from .. import Provider as BaseProvider


# Taiwan jobs from
# http://www.104.com.tw/public/function01/utf8/jsonJobCat.js
# on Fri May 20 23:13:46 CST 2016
class Provider(BaseProvider):
    jobs = [
        "BIOS工程師",
        "CAD／CAM工程師",
        "CNC機台操作人員",
        "CNC電腦程式編排人員",
        "EMC／電子安規工程師",
        "FAE工程師",
        "IC佈局工程師",
        "IC封裝／測試工程師",
        "ISO／品保人員",
        "Internet程式設計師",
        "LCD製程工程師",
        "LCD設備工程師",
        "MES工程師",
        "MIS程式設計師",
        "MIS／網管主管",
        "OP／旅行社人員",
        "PCB佈線工程師",
        "PCB技術人員",
        "RF通訊工程師",
        "SMT工程師",
        "一般動物飼育工作者",
        "不動產產權審核／估價師",
        "不動產經紀人",
        "不動產／商場開發人員",
        "中等學校教師",
        "中醫師",
        "中餐廚師",
        "主持人",
        "主管特別助理",
        "主辦會計",
        "人力資源主管",
        "人力資源人員",
        "人力資源助理",
        "人力／外勞仲介",
        "代書／地政士",
        "估算人員",
        "作曲家",
        "作業員／包裝員",
        "保全人員／警衛",
        "保全技術人員",
        "保安服務工作",
        "保稅人員",
        "保險業務／經紀人",
        "倉儲物流人員",
        "倉管",
        "催收人員",
        "傳播媒體企劃人員",
        "傳銷人員",
        "儲備幹部",
        "光學工程師",
        "光電工程師",
        "光電工程研發主管",
        "內業工程師",
        "公共衛生人員",
        "公共衛生醫師",
        "公家機關人員",
        "券商後線人員",
        "副教授",
        "加油員",
        "助教",
        "助理工程師",
        "助理教授",
        "勞工安全衛生管理人員",
        "勞工安全衛生管理師",
        "包裝設計",
        "化學工程研發人員",
        "化學研究員",
        "化工化學工程師",
        "升學補習班老師",
        "半導體工程師",
        "半導體製程工程師",
        "半導體設備工程師",
        "印前製作／印刷技術人員",
        "可靠度工程師",
        "吊車／起重機設備操作員",
        "呼吸治療師",
        "品牌宣傳及媒體公關",
        "品管／品保主管",
        "品管／品保工程師",
        "品管／檢驗人員",
        "哲學／歷史／政治研究人員",
        "售票／收銀人員",
        "商業設計",
        "商標／專利人員",
        "噴漆人員",
        "國內業務主管",
        "國內業務人員",
        "國外業務主管",
        "國外業務人員",
        "國小學校教師",
        "國貿人員",
        "圖書資料管理人員",
        "土地開發人員",
        "土木技師／土木工程師",
        "地勤人員",
        "地質與地球科學研究員",
        "塑膠射出技術人員",
        "塑膠模具技術人員",
        "塗裝技術人員",
        "壓鑄模具技術人員",
        "外務／快遞／送貨",
        "多媒體動畫設計師",
        "多媒體開發主管",
        "大樓管理員",
        "大貨車司機",
        "天文研究員",
        "太陽能技術工程師",
        "娛樂事業人員",
        "媒體公關／宣傳採買",
        "安全／衛生檢驗人員",
        "安心服務員",
        "安親班老師",
        "客戶服務主管",
        "客戶服務人員",
        "室內設計／裝潢人員",
        "家事服務人員",
        "家庭代工",
        "實驗化驗人員",
        "寵物美容專業人員",
        "專案業務主管",
        "專案管理主管",
        "專案管理師",
        "專科護理師",
        "導播",
        "導演",
        "導遊",
        "小客車司機",
        "小貨車司機",
        "居家服務督導員",
        "展場／櫥窗佈置人員",
        "工務人員／助理",
        "工商登記服務人員",
        "工地監工／主任",
        "工廠主管",
        "工業工程師／生產線規劃",
        "工業設計",
        "工程助理",
        "工程研發主管",
        "工程配管繪圖",
        "工讀生",
        "市場調查／市場分析",
        "平面設計／美編人員",
        "幼教班老師",
        "店長／賣場管理人員",
        "廠務",
        "廠務助理",
        "廣告AE業務人員",
        "廣告企劃主管",
        "廣告文案／企劃",
        "廣告設計",
        "建築師",
        "建築物清潔工",
        "建築物電力系統維修工",
        "建築設計／繪圖人員",
        "影片製作技術人員",
        "律師",
        "復建技術師",
        "微機電工程師",
        "心理學研究人員",
        "志工人員",
        "志願役軍官／士官／士兵",
        "應用科學研究員",
        "成本會計",
        "手工包裝工",
        "才藝類老師",
        "打版人員",
        "技術文件／說明書編譯",
        "按摩／推拿師",
        "排版人員",
        "採購主管",
        "採購人員",
        "採購助理",
        "推土機設備操作員",
        "播音／配音人員",
        "攝影助理",
        "攝影師",
        "放射性設備使用技術員",
        "救生員",
        "教保員",
        "教授",
        "教育訓練人員",
        "整體造型師",
        "數位IC設計工程師",
        "數學研究員",
        "數理補習班老師",
        "文件管理師",
        "文編／校對／文字工作者",
        "旅遊休閒類主管",
        "日式廚師",
        "日文翻譯／口譯人員",
        "星象占卜人員",
        "景觀設計師",
        "會計師",
        "服裝／皮包／鞋類設計",
        "木工",
        "材料研發人員",
        "板金技術員",
        "林木伐運工作者",
        "染整技術人員",
        "查帳／審計人員",
        "核保／保險內勤人員",
        "業務助理",
        "業務支援工程師",
        "樂器製造員",
        "模特兒",
        "機械加工技術人員",
        "機械工程師",
        "機械操作員",
        "機械裝配員",
        "機械設計／繪圖人員",
        "機構工程師",
        "機電技師／工程師",
        "櫃檯接待人員",
        "氣象研究員",
        "水保工程師",
        "水保技師",
        "水利工程師",
        "水產養殖工作者",
        "水電工",
        "水電工程師",
        "水電工程繪圖人員",
        "汽車美容人員",
        "汽車銷售人員",
        "汽車／機車引擎技術人員",
        "汽車／機車技術維修人員",
        "沖壓模具技術人員",
        "油漆工",
        "治療師",
        "法務人員",
        "法務助理",
        "法務／智財主管",
        "法律專業人員",
        "泥水小工",
        "泥水工",
        "洗碗人員",
        "活動企劃人員",
        "派報生／傳單派送",
        "消防員",
        "消防專業人員",
        "混凝土工",
        "清潔工",
        "測試人員",
        "演員",
        "演奏家",
        "演算法開發工程師",
        "焊接及切割技術員",
        "照顧指導員",
        "照顧服務員",
        "熱傳工程師",
        "燈光／音響師",
        "營建主管",
        "營建構造工",
        "營造工程師",
        "營運管理師",
        "營養師",
        "牙醫助理",
        "牙醫師",
        "物理治療師",
        "物理研究員",
        "物管／資材",
        "特殊工程師",
        "特殊教育教師",
        "特用化學工程師",
        "獸醫師",
        "珠寶及貴金屬技術員",
        "珠心算老師",
        "理賠人員",
        "環境工程師",
        "生命禮儀師",
        "生物學專業與研究",
        "生物科技研發人員",
        "生產技術／製程工程師",
        "生產管理主管",
        "生產設備工程師",
        "生管",
        "生管助理",
        "生鮮人員",
        "產品事業處主管",
        "產品企劃主管",
        "產品企劃開發人員",
        "產品售後技術服務",
        "產品管理師",
        "產品維修人員",
        "產品行銷人員",
        "病理藥理研究人員",
        "發包人員",
        "發行企劃／出版人員",
        "砌磚工",
        "研究人員",
        "研究助理",
        "硬體工程研發主管",
        "硬體測試工程師",
        "硬體研發工程師",
        "社工人員",
        "社會／人類學研究人員",
        "秘書",
        "稅務人員",
        "稽核人員",
        "空服員",
        "空調冷凍技術人員",
        "節目助理",
        "節目製作人員",
        "粉末冶金模具技術人員",
        "精密儀器製造工",
        "精密拋光技術人員",
        "系統整合／ERP專案師",
        "系統維護／操作人員",
        "紡織化學工程師",
        "紡織工務",
        "結構技師",
        "統計學研究員",
        "統計精算人員",
        "經營管理主管",
        "網站行銷企劃",
        "網路安全分析師",
        "網路管理工程師",
        "網頁設計師",
        "線切割技術員",
        "總務主管",
        "總務人員",
        "總幹事",
        "總機人員",
        "織品設計",
        "美姿美儀人員",
        "美容工作者",
        "美容類助理",
        "美甲彩繪師",
        "美療／芳療師",
        "美術老師",
        "美術設計",
        "美髮工作者",
        "美髮類助理",
        "翻譯／口譯人員",
        "聲學／噪音工程師",
        "聲樂家",
        "職能治療師",
        "股務人員",
        "自動控制工程師",
        "舞蹈指導與舞蹈家",
        "船務／押匯／報關人員",
        "船長／大副／船員",
        "花藝／園藝人員",
        "英文翻譯／口譯人員",
        "藝術品／珠寶鑑價／拍賣顧問",
        "藝術指導／總監",
        "藥學助理",
        "藥師",
        "融資／信用業務人員",
        "行政主管",
        "行政人員",
        "行政助理",
        "行銷企劃主管",
        "行銷企劃人員",
        "行銷企劃助理",
        "補習班導師／管理人員",
        "補習班老師",
        "製鞋類人員",
        "西餐廚師",
        "西點／蛋糕師",
        "視聽工程類人員",
        "計程車司機",
        "記帳／出納／一般會計",
        "記者／採編",
        "設計助理",
        "診所助理",
        "語文補習班老師",
        "語言治療師",
        "調酒師／吧台人員",
        "調音技術員",
        "講師",
        "護理師",
        "財務分析人員",
        "財務或會計主管",
        "財務會計助理",
        "資料庫管理人員",
        "資料輸入人員",
        "資材主管",
        "資源回收人員",
        "資訊助理人員",
        "資訊專業人員",
        "資訊設備管制人員",
        "車床人員",
        "車縫／裁縫類人員",
        "軟韌體測試工程師",
        "軟體專案主管",
        "軟體專案管理師",
        "軟體設計工程師",
        "農工業用機器裝修工",
        "農林業設備操作員",
        "農藝作物栽培工作者",
        "農藝／畜產研究人員",
        "通信測試維修人員",
        "通訊工程研發主管",
        "通訊軟體工程師",
        "通路開發人員",
        "連鎖店管理人員",
        "遊戲企劃人員",
        "運動教練",
        "運輸交通專業人員",
        "運輸物流類主管",
        "都市／交通規劃人員",
        "醫事放射師",
        "醫事檢驗師",
        "醫師",
        "醫療人員",
        "醫療器材研發工程師",
        "醫療從業人員",
        "醫療設備控制人員",
        "醫藥業務代表",
        "醫藥研發人員",
        "醫院行政管理人員",
        "量測／儀校人員",
        "金屬建材架構人員",
        "金融交易員",
        "金融專業主管",
        "金融承銷員",
        "金融營業員",
        "金融理財專員",
        "金融研究員",
        "銀行辦事員",
        "銑床人員",
        "鍋爐操作技術人員",
        "鐵路車輛駕駛員",
        "鑄造／鍛造模具技術人員",
        "門市／店員／專櫃人員",
        "防水施工人員",
        "防火及建築檢驗人員",
        "零件工程師",
        "雷射操作技術員",
        "電信及電力線路架設工",
        "電信／通訊系統工程師",
        "電台工作人員",
        "電子商務技術主管",
        "電子工程師",
        "電子產品系統工程師",
        "電子設備裝修工",
        "電機工程技術員",
        "電機技師／工程師",
        "電機裝修工",
        "電機設備裝配員",
        "電源工程師",
        "電玩程式設計師",
        "電腦系統分析師",
        "電腦組裝／測試",
        "電腦繪圖人員",
        "電腦補習班老師",
        "電話及電報機裝修工",
        "電話客服類人員",
        "電話行銷人員",
        "電鍍／表面處理技術人員",
        "韌體設計工程師",
        "音樂家",
        "音樂老師",
        "領班",
        "領隊",
        "類廚師",
        "類比IC設計工程師",
        "類講師",
        "顧問人員",
        "飛安人員",
        "飛機裝修工",
        "飛行機師",
        "食品研發人員",
        "食品衛生管理師",
        "飯店工作人員",
        "飯店餐廳主管",
        "餐廚助手",
        "餐飲服務生",
        "駐校代表",
        "驗光師",
        "麵包師",
        "麻醉醫師",
    ]



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    # Source: https://www.wko.at/wirtschaftsrecht/gesellschaftsformen-oesterreich

    formats = (
        "{{last_name}} {{company_suffix}}",
        "{{last_name}} {{last_name}} {{company_suffix}}",
        "{{last_name}} & {{last_name}} {{company_suffix}}",
    )

    company_suffixes = (
        "AG",
        "AG",
        "AG",
        "GesbR",
        "GmbH",
        "GmbH",
        "GmbH",
        "KG",
        "KG",
        "KG",
        "OG",
        "e.V.",
    )



"""
This module exists solely to figure how long a registrant/publication
number may be within an SBN. It's the same as the ISBN implementation
for ean 978, reg_group 0.
"""

from collections import namedtuple
from typing import List

RegistrantRule = namedtuple("RegistrantRule", ["min", "max", "registrant_length"])

# Structure: RULES = [Rule1, Rule2, ...]
RULES: List[RegistrantRule] = [
    RegistrantRule("0000000", "1999999", 2),
    RegistrantRule("2000000", "2279999", 3),
    RegistrantRule("2280000", "2289999", 4),
    RegistrantRule("2290000", "6479999", 3),
    RegistrantRule("6480000", "6489999", 7),
    RegistrantRule("6490000", "6999999", 3),
    RegistrantRule("7000000", "8499999", 4),
    RegistrantRule("8500000", "8999999", 5),
    RegistrantRule("9000000", "9499999", 6),
    RegistrantRule("9500000", "9999999", 7),
]



import re
import unicodedata

from typing import Pattern

_re_pattern: Pattern = re.compile(r"[^\w\s-]", flags=re.U)
_re_pattern_allow_dots: Pattern = re.compile(r"[^\.\w\s-]", flags=re.U)
_re_spaces: Pattern = re.compile(r"[-\s]+", flags=re.U)


def slugify(value: str, allow_dots: bool = False, allow_unicode: bool = False) -> str:
    """
    Converts to lowercase, removes non-word characters (alphanumerics and
    underscores) and converts spaces to hyphens. Also strips leading and
    trailing whitespace. Modified to optionally allow dots.

    Adapted from Django 1.9
    """
    pattern: Pattern = _re_pattern_allow_dots if allow_dots else _re_pattern

    value = str(value)
    if allow_unicode:
        value = unicodedata.normalize("NFKC", value)
        value = pattern.sub("", value).strip().lower()
        return _re_spaces.sub("-", value)
    value = unicodedata.normalize("NFKD", value).encode("ascii", "ignore").decode("ascii")
    value = pattern.sub("", value).strip().lower()
    return _re_spaces.sub("-", value)



from itertools import chain

from faker.typing import OrderedDictType


def add_ordereddicts(*odicts: OrderedDictType) -> OrderedDictType:
    items = [odict.items() for odict in odicts]
    return OrderedDictType(chain(*items))



from faker.utils.decorators import slugify

from .. import Provider as InternetProvider


class Provider(InternetProvider):
    user_name_formats = (
        "{{last_romanized_name}}.{{first_romanized_name}}",
        "{{first_romanized_name}}.{{last_romanized_name}}",
        "{{first_romanized_name}}##",
        "?{{last_romanized_name}}",
    )
    tlds = ("com", "com", "com", "net", "org", "jp", "jp", "jp")

    @slugify
    def domain_word(self) -> str:
        return self.generator.format("last_romanized_name")



from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """
    Implement automotive provider for ``ko_KR`` locale.
    """

    license_formats = (
        "##?####",
        "###?####",
    )

    letter_codes = (
        "가",
        "나",
        "다",
        "라",
        "마",
        "거",
        "너",
        "더",
        "러",
        "머",
        "버",
        "서",
        "어",
        "저",
        "고",
        "노",
        "도",
        "로",
        "모",
        "보",
        "소",
        "오",
        "조",
        "구",
        "누",
        "두",
        "루",
        "무",
        "부",
        "수",
        "우",
        "주",
    )

    def license_plate(self) -> str:
        pattern = self.random_element(self.license_formats)
        letters = "".join(self.letter_codes)
        return self.numerify(self.lexify(pattern, letters=letters))



# Source: https://github.com/fzaninotto/Faker/blob/master/src/Faker/Provider/is_IS/Person.php

from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_male = ("{{first_name_male}} {{last_name_male}}", "{{first_name_male}} {{middle_name}} {{last_name_male}}")

    formats_female = (
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{middle_name}} {{last_name_female}}",
    )

    formats = formats_male + formats_female

    # Icelandic male names
    first_names_male = (
        "Aage",
        "Abel",
        "Abraham",
        "Adam",
        "Addi",
        "Adel",
        "Adíel",
        "Adólf",
        "Adrían",
        "Adríel",
        "Aðalberg",
        "Aðalbergur",
        "Aðalbert",
        "Aðalbjörn",
        "Aðalborgar",
        "Aðalgeir",
        "Aðalmundur",
        "Aðalráður",
        "Aðalsteinn",
        "Aðólf",
        "Agnar",
        "Agni",
        "Albert",
        "Aldar",
        "Alex",
        "Alexander",
        "Alexíus",
        "Alfons",
        "Alfred",
        "Alfreð",
        "Ali",
        "Allan",
        "Alli",
        "Almar",
        "Alrekur",
        "Alvar",
        "Alvin",
        "Amír",
        "Amos",
        "Anders",
        "Andreas",
        "André",
        "Andrés",
        "Andri",
        "Anes",
        "Anfinn",
        "Angantýr",
        "Angi",
        "Annar",
        "Annarr",
        "Annas",
        "Annel",
        "Annes",
        "Anthony",
        "Anton",
        "Antoníus",
        "Aran",
        "Arent",
        "Ares",
        "Ari",
        "Arilíus",
        "Arinbjörn",
        "Aríel",
        "Aríus",
        "Arnald",
        "Arnaldur",
        "Arnar",
        "Arnberg",
        "Arnbergur",
        "Arnbjörn",
        "Arndór",
        "Arnes",
        "Arnfinnur",
        "Arnfreyr",
        "Arngeir",
        "Arngils",
        "Arngrímur",
        "Arnkell",
        "Arnlaugur",
        "Arnleifur",
        "Arnljótur",
        "Arnmóður",
        "Arnmundur",
        "Arnoddur",
        "Arnold",
        "Arnór",
        "Arnsteinn",
        "Arnúlfur",
        "Arnviður",
        "Arnþór",
        "Aron",
        "Arthur",
        "Arthúr",
        "Artúr",
        "Asael",
        "Askur",
        "Aspar",
        "Atlas",
        "Atli",
        "Auðbergur",
        "Auðbert",
        "Auðbjörn",
        "Auðgeir",
        "Auðkell",
        "Auðmundur",
        "Auðólfur",
        "Auðun",
        "Auðunn",
        "Austar",
        "Austmann",
        "Austmar",
        "Austri",
        "Axel",
        "Ágúst",
        "Áki",
        "Álfar",
        "Álfgeir",
        "Álfgrímur",
        "Álfur",
        "Álfþór",
        "Ámundi",
        "Árbjartur",
        "Árbjörn",
        "Árelíus",
        "Árgeir",
        "Árgils",
        "Ármann",
        "Árni",
        "Ársæll",
        "Ás",
        "Ásberg",
        "Ásbergur",
        "Ásbjörn",
        "Ásgautur",
        "Ásgeir",
        "Ásgils",
        "Ásgrímur",
        "Ási",
        "Áskell",
        "Áslaugur",
        "Áslákur",
        "Ásmar",
        "Ásmundur",
        "Ásólfur",
        "Ásröður",
        "Ástbjörn",
        "Ástgeir",
        "Ástmar",
        "Ástmundur",
        "Ástráður",
        "Ástríkur",
        "Ástvald",
        "Ástvaldur",
        "Ástvar",
        "Ástvin",
        "Ástþór",
        "Ásvaldur",
        "Ásvarður",
        "Ásþór",
        "Baldur",
        "Baldvin",
        "Baldwin",
        "Baltasar",
        "Bambi",
        "Barði",
        "Barri",
        "Bassi",
        "Bastían",
        "Baugur",
        "Bárður",
        "Beinir",
        "Beinteinn",
        "Beitir",
        "Bekan",
        "Benedikt",
        "Benidikt",
        "Benjamín",
        "Benoný",
        "Benóní",
        "Benóný",
        "Bent",
        "Berent",
        "Berg",
        "Bergfinnur",
        "Berghreinn",
        "Bergjón",
        "Bergmann",
        "Bergmar",
        "Bergmundur",
        "Bergsteinn",
        "Bergsveinn",
        "Bergur",
        "Bergvin",
        "Bergþór",
        "Bernhard",
        "Bernharð",
        "Bernharður",
        "Berni",
        "Bernódus",
        "Bersi",
        "Bertel",
        "Bertram",
        "Bessi",
        "Betúel",
        "Bill",
        "Birgir",
        "Birkir",
        "Birnir",
        "Birtingur",
        "Birtir",
        "Bjargar",
        "Bjargmundur",
        "Bjargþór",
        "Bjarkan",
        "Bjarkar",
        "Bjarki",
        "Bjarmar",
        "Bjarmi",
        "Bjarnar",
        "Bjarnfinnur",
        "Bjarnfreður",
        "Bjarnharður",
        "Bjarnhéðinn",
        "Bjarni",
        "Bjarnlaugur",
        "Bjarnleifur",
        "Bjarnólfur",
        "Bjarnsteinn",
        "Bjarnþór",
        "Bjartmann",
        "Bjartmar",
        "Bjartur",
        "Bjartþór",
        "Bjólan",
        "Bjólfur",
        "Björgmundur",
        "Björgólfur",
        "Björgúlfur",
        "Björgvin",
        "Björn",
        "Björnólfur",
        "Blængur",
        "Blær",
        "Blævar",
        "Boði",
        "Bogi",
        "Bolli",
        "Borgar",
        "Borgúlfur",
        "Borgþór",
        "Bóas",
        "Bói",
        "Bótólfur",
        "Bragi",
        "Brandur",
        "Breki",
        "Bresi",
        "Brestir",
        "Brimar",
        "Brimi",
        "Brimir",
        "Brími",
        "Brjánn",
        "Broddi",
        "Bruno",
        "Bryngeir",
        "Brynjar",
        "Brynjólfur",
        "Brynjúlfur",
        "Brynleifur",
        "Brynsteinn",
        "Bryntýr",
        "Brynþór",
        "Burkni",
        "Búi",
        "Búri",
        "Bæring",
        "Bæringur",
        "Bæron",
        "Böðvar",
        "Börkur",
        "Carl",
        "Cecil",
        "Christian",
        "Christopher",
        "Cýrus",
        "Daði",
        "Dagbjartur",
        "Dagfari",
        "Dagfinnur",
        "Daggeir",
        "Dagmann",
        "Dagnýr",
        "Dagur",
        "Dagþór",
        "Dalbert",
        "Dalli",
        "Dalmann",
        "Dalmar",
        "Dalvin",
        "Damjan",
        "Dan",
        "Danelíus",
        "Daniel",
        "Danival",
        "Daníel",
        "Daníval",
        "Dante",
        "Daríus",
        "Darri",
        "Davíð",
        "Demus",
        "Deníel",
        "Dennis",
        "Diðrik",
        "Díómedes",
        "Dofri",
        "Dolli",
        "Dominik",
        "Dómald",
        "Dómaldi",
        "Dómaldur",
        "Dónald",
        "Dónaldur",
        "Dór",
        "Dóri",
        "Dósóþeus",
        "Draupnir",
        "Dreki",
        "Drengur",
        "Dufgus",
        "Dufþakur",
        "Dugfús",
        "Dúi",
        "Dúnn",
        "Dvalinn",
        "Dýri",
        "Dýrmundur",
        "Ebbi",
        "Ebeneser",
        "Ebenezer",
        "Eberg",
        "Edgar",
        "Edilon",
        "Edílon",
        "Edvard",
        "Edvin",
        "Edward",
        "Eðvald",
        "Eðvar",
        "Eðvarð",
        "Efraím",
        "Eggert",
        "Eggþór",
        "Egill",
        "Eiðar",
        "Eiður",
        "Eikar",
        "Eilífur",
        "Einar",
        "Einir",
        "Einvarður",
        "Einþór",
        "Eiríkur",
        "Eivin",
        "Elberg",
        "Elbert",
        "Eldar",
        "Eldgrímur",
        "Eldjárn",
        "Eldmar",
        "Eldon",
        "Eldór",
        "Eldur",
        "Elentínus",
        "Elfar",
        "Elfráður",
        "Elimar",
        "Elinór",
        "Elis",
        "Elí",
        "Elías",
        "Elíeser",
        "Elímar",
        "Elínbergur",
        "Elínmundur",
        "Elínór",
        "Elís",
        "Ellert",
        "Elli",
        "Elliði",
        "Ellís",
        "Elmar",
        "Elvar",
        "Elvin",
        "Elvis",
        "Emanúel",
        "Embrek",
        "Emerald",
        "Emil",
        "Emmanúel",
        "Engilbert",
        "Engilbjartur",
        "Engiljón",
        "Engill",
        "Enok",
        "Eric",
        "Erik",
        "Erlar",
        "Erlendur",
        "Erling",
        "Erlingur",
        "Ernestó",
        "Ernir",
        "Ernst",
        "Eron",
        "Erpur",
        "Esekíel",
        "Esjar",
        "Esra",
        "Estefan",
        "Evald",
        "Evan",
        "Evert",
        "Eyberg",
        "Eyjólfur",
        "Eylaugur",
        "Eyleifur",
        "Eymar",
        "Eymundur",
        "Eyríkur",
        "Eysteinn",
        "Eyvar",
        "Eyvindur",
        "Eyþór",
        "Fabrisíus",
        "Falgeir",
        "Falur",
        "Fannar",
        "Fannberg",
        "Fanngeir",
        "Fáfnir",
        "Fálki",
        "Felix",
        "Fengur",
        "Fenrir",
        "Ferdinand",
        "Ferdínand",
        "Fertram",
        "Feykir",
        "Filip",
        "Filippus",
        "Finn",
        "Finnbjörn",
        "Finnbogi",
        "Finngeir",
        "Finnjón",
        "Finnlaugur",
        "Finnur",
        "Finnvarður",
        "Fífill",
        "Fjalar",
        "Fjarki",
        "Fjólar",
        "Fjólmundur",
        "Fjölnir",
        "Fjölvar",
        "Fjörnir",
        "Flemming",
        "Flosi",
        "Flóki",
        "Flórent",
        "Flóvent",
        "Forni",
        "Fossmar",
        "Fólki",
        "Francis",
        "Frank",
        "Franklín",
        "Frans",
        "Franz",
        "Fránn",
        "Frár",
        "Freybjörn",
        "Freygarður",
        "Freymar",
        "Freymóður",
        "Freymundur",
        "Freyr",
        "Freysteinn",
        "Freyviður",
        "Freyþór",
        "Friðberg",
        "Friðbergur",
        "Friðbert",
        "Friðbjörn",
        "Friðfinnur",
        "Friðgeir",
        "Friðjón",
        "Friðlaugur",
        "Friðleifur",
        "Friðmann",
        "Friðmar",
        "Friðmundur",
        "Friðrik",
        "Friðsteinn",
        "Friður",
        "Friðvin",
        "Friðþjófur",
        "Friðþór",
        "Friedrich",
        "Fritz",
        "Frímann",
        "Frosti",
        "Fróði",
        "Fróðmar",
        "Funi",
        "Fúsi",
        "Fylkir",
        "Gabriel",
        "Gabríel",
        "Gael",
        "Galdur",
        "Gamalíel",
        "Garðar",
        "Garibaldi",
        "Garpur",
        "Garri",
        "Gaui",
        "Gaukur",
        "Gauti",
        "Gautrekur",
        "Gautur",
        "Gautviður",
        "Geir",
        "Geirarður",
        "Geirfinnur",
        "Geirharður",
        "Geirhjörtur",
        "Geirhvatur",
        "Geiri",
        "Geirlaugur",
        "Geirleifur",
        "Geirmundur",
        "Geirólfur",
        "Geirröður",
        "Geirtryggur",
        "Geirvaldur",
        "Geirþjófur",
        "Geisli",
        "Gellir",
        "Georg",
        "Gerald",
        "Gerðar",
        "Geri",
        "Gestur",
        "Gilbert",
        "Gilmar",
        "Gils",
        "Gissur",
        "Gizur",
        "Gídeon",
        "Gígjar",
        "Gísli",
        "Gjúki",
        "Glói",
        "Glúmur",
        "Gneisti",
        "Gnúpur",
        "Gnýr",
        "Goði",
        "Goðmundur",
        "Gottskálk",
        "Gottsveinn",
        "Gói",
        "Grani",
        "Grankell",
        "Gregor",
        "Greipur",
        "Greppur",
        "Gretar",
        "Grettir",
        "Grétar",
        "Grímar",
        "Grímkell",
        "Grímlaugur",
        "Grímnir",
        "Grímólfur",
        "Grímur",
        "Grímúlfur",
        "Guðberg",
        "Guðbergur",
        "Guðbjarni",
        "Guðbjartur",
        "Guðbjörn",
        "Guðbrandur",
        "Guðfinnur",
        "Guðfreður",
        "Guðgeir",
        "Guðjón",
        "Guðlaugur",
        "Guðleifur",
        "Guðleikur",
        "Guðmann",
        "Guðmar",
        "Guðmon",
        "Guðmundur",
        "Guðni",
        "Guðráður",
        "Guðröður",
        "Guðsteinn",
        "Guðvarður",
        "Guðveigur",
        "Guðvin",
        "Guðþór",
        "Gumi",
        "Gunnar",
        "Gunnberg",
        "Gunnbjörn",
        "Gunndór",
        "Gunngeir",
        "Gunnhallur",
        "Gunnlaugur",
        "Gunnleifur",
        "Gunnólfur",
        "Gunnóli",
        "Gunnröður",
        "Gunnsteinn",
        "Gunnvaldur",
        "Gunnþór",
        "Gustav",
        "Gutti",
        "Guttormur",
        "Gústaf",
        "Gústav",
        "Gylfi",
        "Gyrðir",
        "Gýgjar",
        "Gýmir",
        "Haddi",
        "Haddur",
        "Hafberg",
        "Hafgrímur",
        "Hafliði",
        "Hafnar",
        "Hafni",
        "Hafsteinn",
        "Hafþór",
        "Hagalín",
        "Hagbarður",
        "Hagbert",
        "Haki",
        "Hallberg",
        "Hallbjörn",
        "Halldór",
        "Hallfreður",
        "Hallgarður",
        "Hallgeir",
        "Hallgils",
        "Hallgrímur",
        "Hallkell",
        "Hallmann",
        "Hallmar",
        "Hallmundur",
        "Hallsteinn",
        "Hallur",
        "Hallvarður",
        "Hallþór",
        "Hamar",
        "Hannes",
        "Hannibal",
        "Hans",
        "Harald",
        "Haraldur",
        "Harri",
        "Harry",
        "Harrý",
        "Hartmann",
        "Hartvig",
        "Hauksteinn",
        "Haukur",
        "Haukvaldur",
        "Hákon",
        "Háleygur",
        "Hálfdan",
        "Hálfdán",
        "Hámundur",
        "Hárekur",
        "Hárlaugur",
        "Hásteinn",
        "Hávar",
        "Hávarður",
        "Hávarr",
        "Hávarr",
        "Heiðar",
        "Heiðarr",
        "Heiðberg",
        "Heiðbert",
        "Heiðlindur",
        "Heiðmann",
        "Heiðmar",
        "Heiðmundur",
        "Heiðrekur",
        "Heikir",
        "Heilmóður",
        "Heimir",
        "Heinrekur",
        "Heisi",
        "Hektor",
        "Helgi",
        "Helmút",
        "Hemmert",
        "Hendrik",
        "Henning",
        "Henrik",
        "Henry",
        "Henrý",
        "Herbert",
        "Herbjörn",
        "Herfinnur",
        "Hergeir",
        "Hergill",
        "Hergils",
        "Herjólfur",
        "Herlaugur",
        "Herleifur",
        "Herluf",
        "Hermann",
        "Hermóður",
        "Hermundur",
        "Hersir",
        "Hersteinn",
        "Hersveinn",
        "Hervar",
        "Hervarður",
        "Hervin",
        "Héðinn",
        "Hilaríus",
        "Hilbert",
        "Hildar",
        "Hildibergur",
        "Hildibrandur",
        "Hildigeir",
        "Hildiglúmur",
        "Hildimar",
        "Hildimundur",
        "Hildingur",
        "Hildir",
        "Hildiþór",
        "Hilmar",
        "Hilmir",
        "Himri",
        "Hinrik",
        "Híram",
        "Hjallkár",
        "Hjalti",
        "Hjarnar",
        "Hjálmar",
        "Hjálmgeir",
        "Hjálmtýr",
        "Hjálmur",
        "Hjálmþór",
        "Hjörleifur",
        "Hjörtur",
        "Hjörtþór",
        "Hjörvar",
        "Hleiðar",
        "Hlégestur",
        "Hlér",
        "Hlini",
        "Hlíðar",
        "Hlíðberg",
        "Hlífar",
        "Hljómur",
        "Hlynur",
        "Hlöðmundur",
        "Hlöður",
        "Hlöðvarður",
        "Hlöðver",
        "Hnefill",
        "Hnikar",
        "Hnikarr",
        "Holgeir",
        "Holger",
        "Holti",
        "Hólm",
        "Hólmar",
        "Hólmbert",
        "Hólmfastur",
        "Hólmgeir",
        "Hólmgrímur",
        "Hólmkell",
        "Hólmsteinn",
        "Hólmþór",
        "Hóseas",
        "Hrafn",
        "Hrafnar",
        "Hrafnbergur",
        "Hrafnkell",
        "Hrafntýr",
        "Hrannar",
        "Hrappur",
        "Hraunar",
        "Hreggviður",
        "Hreiðar",
        "Hreiðmar",
        "Hreimur",
        "Hreinn",
        "Hringur",
        "Hrímnir",
        "Hrollaugur",
        "Hrolleifur",
        "Hróaldur",
        "Hróar",
        "Hróbjartur",
        "Hróðgeir",
        "Hróðmar",
        "Hróðólfur",
        "Hróðvar",
        "Hrói",
        "Hrólfur",
        "Hrómundur",
        "Hrútur",
        "Hrærekur",
        "Hugberg",
        "Hugi",
        "Huginn",
        "Hugleikur",
        "Hugo",
        "Hugó",
        "Huldar",
        "Huxley",
        "Húbert",
        "Húgó",
        "Húmi",
        "Húnbogi",
        "Húni",
        "Húnn",
        "Húnröður",
        "Hvannar",
        "Hyltir",
        "Hylur",
        "Hængur",
        "Hænir",
        "Höður",
        "Högni",
        "Hörður",
        "Höskuldur",
        "Illugi",
        "Immanúel",
        "Indriði",
        "Ingberg",
        "Ingi",
        "Ingiberg",
        "Ingibergur",
        "Ingibert",
        "Ingibjartur",
        "Ingibjörn",
        "Ingileifur",
        "Ingimagn",
        "Ingimar",
        "Ingimundur",
        "Ingivaldur",
        "Ingiþór",
        "Ingjaldur",
        "Ingmar",
        "Ingólfur",
        "Ingvaldur",
        "Ingvar",
        "Ingvi",
        "Ingþór",
        "Ismael",
        "Issi",
        "Ían",
        "Ígor",
        "Ími",
        "Ísak",
        "Ísar",
        "Ísarr",
        "Ísbjörn",
        "Íseldur",
        "Ísgeir",
        "Ísidór",
        "Ísleifur",
        "Ísmael",
        "Ísmar",
        "Ísólfur",
        "Ísrael",
        "Ívan",
        "Ívar",
        "Jack",
        "Jafet",
        "Jaki",
        "Jakob",
        "Jakop",
        "Jamil",
        "Jan",
        "Janus",
        "Jarl",
        "Jason",
        "Járngrímur",
        "Játgeir",
        "Játmundur",
        "Játvarður",
        "Jenni",
        "Jens",
        "Jeremías",
        "Jes",
        "Jesper",
        "Jochum",
        "Johan",
        "John",
        "Joshua",
        "Jóakim",
        "Jóann",
        "Jóel",
        "Jóhann",
        "Jóhannes",
        "Jói",
        "Jómar",
        "Jómundur",
        "Jón",
        "Jónar",
        "Jónas",
        "Jónatan",
        "Jónbjörn",
        "Jóndór",
        "Jóngeir",
        "Jónmundur",
        "Jónsteinn",
        "Jónþór",
        "Jósafat",
        "Jósavin",
        "Jósef",
        "Jósep",
        "Jósteinn",
        "Jósúa",
        "Jóvin",
        "Julian",
        "Júlí",
        "Júlían",
        "Júlíus",
        "Júní",
        "Júníus",
        "Júrek",
        "Jökull",
        "Jörfi",
        "Jörgen",
        "Jörmundur",
        "Jörri",
        "Jörundur",
        "Jörvar",
        "Jörvi",
        "Kaj",
        "Kakali",
        "Kaktus",
        "Kaldi",
        "Kaleb",
        "Kali",
        "Kalman",
        "Kalmann",
        "Kalmar",
        "Kaprasíus",
        "Karel",
        "Karim",
        "Karkur",
        "Karl",
        "Karles",
        "Karli",
        "Karvel",
        "Kaspar",
        "Kasper",
        "Kastíel",
        "Katarínus",
        "Kató",
        "Kár",
        "Kári",
        "Keran",
        "Ketilbjörn",
        "Ketill",
        "Kilían",
        "Kiljan",
        "Kjalar",
        "Kjallakur",
        "Kjaran",
        "Kjartan",
        "Kjarval",
        "Kjárr",
        "Kjói",
        "Klemens",
        "Klemenz",
        "Klængur",
        "Knútur",
        "Knörr",
        "Koðrán",
        "Koggi",
        "Kolbeinn",
        "Kolbjörn",
        "Kolfinnur",
        "Kolgrímur",
        "Kolmar",
        "Kolskeggur",
        "Kolur",
        "Kolviður",
        "Konráð",
        "Konstantínus",
        "Kormákur",
        "Kornelíus",
        "Kort",
        "Kópur",
        "Kraki",
        "Kris",
        "Kristall",
        "Kristberg",
        "Kristbergur",
        "Kristbjörn",
        "Kristdór",
        "Kristens",
        "Krister",
        "Kristfinnur",
        "Kristgeir",
        "Kristian",
        "Kristinn",
        "Kristján",
        "Kristjón",
        "Kristlaugur",
        "Kristleifur",
        "Kristmann",
        "Kristmar",
        "Kristmundur",
        "Kristofer",
        "Kristófer",
        "Kristvaldur",
        "Kristvarður",
        "Kristvin",
        "Kristþór",
        "Krummi",
        "Kveldúlfur",
        "Lambert",
        "Lars",
        "Laufar",
        "Laugi",
        "Lauritz",
        "Lár",
        "Lárent",
        "Lárentíus",
        "Lárus",
        "Leiðólfur",
        "Leif",
        "Leifur",
        "Leiknir",
        "Leo",
        "Leon",
        "Leonard",
        "Leonhard",
        "Leó",
        "Leópold",
        "Leví",
        "Lér",
        "Liljar",
        "Lindar",
        "Lindberg",
        "Línberg",
        "Líni",
        "Ljósálfur",
        "Ljótur",
        "Ljúfur",
        "Loðmundur",
        "Loftur",
        "Logi",
        "Loki",
        "Lórens",
        "Lórenz",
        "Ludvig",
        "Lundi",
        "Lúðvíg",
        "Lúðvík",
        "Lúkas",
        "Lúter",
        "Lúther",
        "Lyngar",
        "Lýður",
        "Lýtingur",
        "Maggi",
        "Magngeir",
        "Magni",
        "Magnús",
        "Magnþór",
        "Makan",
        "Manfred",
        "Manfreð",
        "Manúel",
        "Mar",
        "Marbjörn",
        "Marel",
        "Margeir",
        "Margrímur",
        "Mari",
        "Marijón",
        "Marinó",
        "Marías",
        "Marínó",
        "Marís",
        "Maríus",
        "Marjón",
        "Markó",
        "Markús",
        "Markþór",
        "Maron",
        "Marri",
        "Mars",
        "Marsellíus",
        "Marteinn",
        "Marten",
        "Marthen",
        "Martin",
        "Marvin",
        "Mathías",
        "Matthías",
        "Matti",
        "Mattías",
        "Max",
        "Maximus",
        "Máni",
        "Már",
        "Márus",
        "Mekkinó",
        "Melkíor",
        "Melkólmur",
        "Melrakki",
        "Mensalder",
        "Merkúr",
        "Methúsalem",
        "Metúsalem",
        "Meyvant",
        "Michael",
        "Mikael",
        "Mikjáll",
        "Mikkael",
        "Mikkel",
        "Mildinberg",
        "Mías",
        "Mímir",
        "Míó",
        "Mír",
        "Mjöllnir",
        "Mjölnir",
        "Moli",
        "Morgan",
        "Moritz",
        "Mosi",
        "Móði",
        "Móri",
        "Mórits",
        "Móses",
        "Muggur",
        "Muni",
        "Muninn",
        "Múli",
        "Myrkvi",
        "Mýrkjartan",
        "Mörður",
        "Narfi",
        "Natan",
        "Natanael",
        "Nataníel",
        "Náttmörður",
        "Náttúlfur",
        "Neisti",
        "Nenni",
        "Neptúnus",
        "Nicolas",
        "Nikanor",
        "Nikolai",
        "Nikolas",
        "Nikulás",
        "Nils",
        "Níels",
        "Níls",
        "Njáll",
        "Njörður",
        "Nonni",
        "Norbert",
        "Norðmann",
        "Normann",
        "Nóam",
        "Nóel",
        "Nói",
        "Nóni",
        "Nóri",
        "Nóvember",
        "Númi",
        "Nývarð",
        "Nökkvi",
        "Oddbergur",
        "Oddbjörn",
        "Oddfreyr",
        "Oddgeir",
        "Oddi",
        "Oddkell",
        "Oddleifur",
        "Oddmar",
        "Oddsteinn",
        "Oddur",
        "Oddvar",
        "Oddþór",
        "Oktavíus",
        "Októ",
        "Októvíus",
        "Olaf",
        "Olav",
        "Olgeir",
        "Oliver",
        "Olivert",
        "Orfeus",
        "Ormar",
        "Ormur",
        "Orri",
        "Orvar",
        "Otkell",
        "Otri",
        "Otti",
        "Ottó",
        "Otur",
        "Óðinn",
        "Ófeigur",
        "Ólafur",
        "Óli",
        "Óliver",
        "Ólíver",
        "Ómar",
        "Ómi",
        "Óskar",
        "Ósvald",
        "Ósvaldur",
        "Ósvífur",
        "Óttar",
        "Óttarr",
        "Parmes",
        "Patrek",
        "Patrekur",
        "Patrick",
        "Patrik",
        "Páll",
        "Pálmar",
        "Pálmi",
        "Pedró",
        "Per",
        "Peter",
        "Pétur",
        "Pjetur",
        "Príor",
        "Rafael",
        "Rafn",
        "Rafnar",
        "Rafnkell",
        "Ragnar",
        "Ragúel",
        "Randver",
        "Rannver",
        "Rasmus",
        "Ráðgeir",
        "Ráðvarður",
        "Refur",
        "Reginbaldur",
        "Reginn",
        "Reidar",
        "Reifnir",
        "Reimar",
        "Reinar",
        "Reinhart",
        "Reinhold",
        "Reynald",
        "Reynar",
        "Reynir",
        "Reyr",
        "Richard",
        "Rikharð",
        "Rikharður",
        "Ríkarður",
        "Ríkharð",
        "Ríkharður",
        "Ríó",
        "Robert",
        "Rolf",
        "Ronald",
        "Róbert",
        "Rólant",
        "Róman",
        "Rómeó",
        "Rósant",
        "Rósar",
        "Rósberg",
        "Rósenberg",
        "Rósi",
        "Rósinberg",
        "Rósinkar",
        "Rósinkrans",
        "Rósmann",
        "Rósmundur",
        "Rudolf",
        "Runi",
        "Runólfur",
        "Rúbar",
        "Rúben",
        "Rúdólf",
        "Rúnar",
        "Rúrik",
        "Rútur",
        "Röðull",
        "Rögnvald",
        "Rögnvaldur",
        "Rögnvar",
        "Rökkvi",
        "Safír",
        "Sakarías",
        "Salmann",
        "Salmar",
        "Salómon",
        "Salvar",
        "Samson",
        "Samúel",
        "Sandel",
        "Sandri",
        "Sandur",
        "Saxi",
        "Sebastian",
        "Sebastían",
        "Seifur",
        "Seimur",
        "Sesar",
        "Sesil",
        "Sigbergur",
        "Sigbert",
        "Sigbjartur",
        "Sigbjörn",
        "Sigdór",
        "Sigfastur",
        "Sigfinnur",
        "Sigfreður",
        "Sigfús",
        "Siggeir",
        "Sighvatur",
        "Sigjón",
        "Siglaugur",
        "Sigmann",
        "Sigmar",
        "Sigmundur",
        "Signar",
        "Sigri",
        "Sigríkur",
        "Sigsteinn",
        "Sigtryggur",
        "Sigtýr",
        "Sigur",
        "Sigurbaldur",
        "Sigurberg",
        "Sigurbergur",
        "Sigurbjarni",
        "Sigurbjartur",
        "Sigurbjörn",
        "Sigurbrandur",
        "Sigurdór",
        "Sigurður",
        "Sigurfinnur",
        "Sigurgeir",
        "Sigurgestur",
        "Sigurgísli",
        "Sigurgrímur",
        "Sigurhans",
        "Sigurhjörtur",
        "Sigurjón",
        "Sigurkarl",
        "Sigurlaugur",
        "Sigurlás",
        "Sigurleifur",
        "Sigurliði",
        "Sigurlinni",
        "Sigurmann",
        "Sigurmar",
        "Sigurmon",
        "Sigurmundur",
        "Sigurnýas",
        "Sigurnýjas",
        "Siguroddur",
        "Siguróli",
        "Sigurpáll",
        "Sigursteinn",
        "Sigursveinn",
        "Sigurvaldi",
        "Sigurvin",
        "Sigurþór",
        "Sigvaldi",
        "Sigvarður",
        "Sigþór",
        "Silli",
        "Sindri",
        "Símon",
        "Sírnir",
        "Sírus",
        "Sívar",
        "Sjafnar",
        "Skafti",
        "Skapti",
        "Skarphéðinn",
        "Skefill",
        "Skeggi",
        "Skíði",
        "Skírnir",
        "Skjöldur",
        "Skorri",
        "Skuggi",
        "Skúli",
        "Skúta",
        "Skær",
        "Skæringur",
        "Smári",
        "Smiður",
        "Smyrill",
        "Snjóki",
        "Snjólaugur",
        "Snjólfur",
        "Snorri",
        "Snæbjartur",
        "Snæbjörn",
        "Snæhólm",
        "Snælaugur",
        "Snær",
        "Snæringur",
        "Snævar",
        "Snævarr",
        "Snæþór",
        "Soffanías",
        "Sophanías",
        "Sophus",
        "Sófónías",
        "Sófus",
        "Sókrates",
        "Sólberg",
        "Sólbergur",
        "Sólbjartur",
        "Sólbjörn",
        "Sólimann",
        "Sólmar",
        "Sólmundur",
        "Sólon",
        "Sólver",
        "Sólvin",
        "Spartakus",
        "Sporði",
        "Spói",
        "Stanley",
        "Stapi",
        "Starkaður",
        "Starri",
        "Stefan",
        "Stefán",
        "Stefnir",
        "Steinar",
        "Steinarr",
        "Steinberg",
        "Steinbergur",
        "Steinbjörn",
        "Steindór",
        "Steinfinnur",
        "Steingrímur",
        "Steini",
        "Steinkell",
        "Steinmann",
        "Steinmar",
        "Steinmóður",
        "Steinn",
        "Steinólfur",
        "Steinröður",
        "Steinvarður",
        "Steinþór",
        "Stirnir",
        "Stígur",
        "Stormur",
        "Stórólfur",
        "Sturla",
        "Sturlaugur",
        "Sturri",
        "Styr",
        "Styrbjörn",
        "Styrkár",
        "Styrmir",
        "Styrr",
        "Sumarliði",
        "Svafar",
        "Svali",
        "Svan",
        "Svanberg",
        "Svanbergur",
        "Svanbjörn",
        "Svangeir",
        "Svanhólm",
        "Svani",
        "Svanlaugur",
        "Svanmundur",
        "Svanur",
        "Svanþór",
        "Svavar",
        "Sváfnir",
        "Sveinar",
        "Sveinberg",
        "Sveinbjartur",
        "Sveinbjörn",
        "Sveinjón",
        "Sveinlaugur",
        "Sveinmar",
        "Sveinn",
        "Sveinungi",
        "Sveinþór",
        "Svend",
        "Sverre",
        "Sverrir",
        "Svölnir",
        "Svörfuður",
        "Sýrus",
        "Sæberg",
        "Sæbergur",
        "Sæbjörn",
        "Sæi",
        "Sælaugur",
        "Sæmann",
        "Sæmundur",
        "Sær",
        "Sævald",
        "Sævaldur",
        "Sævar",
        "Sævarr",
        "Sævin",
        "Sæþór",
        "Sölmundur",
        "Sölvar",
        "Sölvi",
        "Sören",
        "Sörli",
        "Tandri",
        "Tarfur",
        "Teitur",
        "Theodór",
        "Theódór",
        "Thomas",
        "Thor",
        "Thorberg",
        "Thór",
        "Tindar",
        "Tindri",
        "Tindur",
        "Tinni",
        "Tími",
        "Tímon",
        "Tímoteus",
        "Tímóteus",
        "Tístran",
        "Tjaldur",
        "Tjörfi",
        "Tjörvi",
        "Tobías",
        "Tolli",
        "Tonni",
        "Torfi",
        "Tóbías",
        "Tói",
        "Tóki",
        "Tómas",
        "Tór",
        "Trausti",
        "Tristan",
        "Trostan",
        "Trúmann",
        "Tryggvi",
        "Tumas",
        "Tumi",
        "Tyrfingur",
        "Týr",
        "Ubbi",
        "Uggi",
        "Ulrich",
        "Uni",
        "Unnar",
        "Unnbjörn",
        "Unndór",
        "Unnsteinn",
        "Unnþór",
        "Urðar",
        "Uxi",
        "Úddi",
        "Úlfar",
        "Úlfgeir",
        "Úlfhéðinn",
        "Úlfkell",
        "Úlfljótur",
        "Úlftýr",
        "Úlfur",
        "Úlrik",
        "Úranus",
        "Vagn",
        "Vakur",
        "Valberg",
        "Valbergur",
        "Valbjörn",
        "Valbrandur",
        "Valdemar",
        "Valdi",
        "Valdimar",
        "Valdór",
        "Valentín",
        "Valentínus",
        "Valgarð",
        "Valgarður",
        "Valgeir",
        "Valíant",
        "Vallaður",
        "Valmar",
        "Valmundur",
        "Valsteinn",
        "Valter",
        "Valtýr",
        "Valur",
        "Valves",
        "Valþór",
        "Varmar",
        "Vatnar",
        "Váli",
        "Vápni",
        "Veigar",
        "Veigur",
        "Ver",
        "Vermundur",
        "Vernharð",
        "Vernharður",
        "Vestar",
        "Vestmar",
        "Veturliði",
        "Vébjörn",
        "Végeir",
        "Vékell",
        "Vélaugur",
        "Vémundur",
        "Vésteinn",
        "Victor",
        "Viðar",
        "Vigfús",
        "Viggó",
        "Vignir",
        "Vigri",
        "Vigtýr",
        "Vigur",
        "Vikar",
        "Viktor",
        "Vilberg",
        "Vilbergur",
        "Vilbert",
        "Vilbjörn",
        "Vilbogi",
        "Vilbrandur",
        "Vilgeir",
        "Vilhelm",
        "Vilhjálmur",
        "Vili",
        "Viljar",
        "Vilji",
        "Villi",
        "Vilmar",
        "Vilmundur",
        "Vincent",
        "Vinjar",
        "Virgill",
        "Víðar",
        "Víðir",
        "Vífill",
        "Víglundur",
        "Vígmar",
        "Vígmundur",
        "Vígsteinn",
        "Vígþór",
        "Víkingur",
        "Vopni",
        "Vorm",
        "Vöggur",
        "Völundur",
        "Vörður",
        "Vöttur",
        "Walter",
        "Werner",
        "Wilhelm",
        "Willard",
        "William",
        "Willum",
        "Ylur",
        "Ymir",
        "Yngvar",
        "Yngvi",
        "Yrkill",
        "Ýmir",
        "Ýrar",
        "Zakaría",
        "Zakarías",
        "Zophanías",
        "Zophonías",
        "Zóphanías",
        "Zóphonías",
        "Þangbrandur",
        "Þengill",
        "Þeyr",
        "Þiðrandi",
        "Þiðrik",
        "Þinur",
        "Þjálfi",
        "Þjóðann",
        "Þjóðbjörn",
        "Þjóðgeir",
        "Þjóðleifur",
        "Þjóðmar",
        "Þjóðólfur",
        "Þjóðrekur",
        "Þjóðvarður",
        "Þjóstar",
        "Þjóstólfur",
        "Þorberg",
        "Þorbergur",
        "Þorbjörn",
        "Þorbrandur",
        "Þorfinnur",
        "Þorgarður",
        "Þorgautur",
        "Þorgeir",
        "Þorgestur",
        "Þorgils",
        "Þorgísl",
        "Þorgnýr",
        "Þorgrímur",
        "Þorkell",
        "Þorlaugur",
        "Þorlákur",
        "Þorleifur",
        "Þorleikur",
        "Þormar",
        "Þormóður",
        "Þormundur",
        "Þorri",
        "Þorsteinn",
        "Þorvaldur",
        "Þorvar",
        "Þorvarður",
        "Þór",
        "Þórar",
        "Þórarinn",
        "Þórbergur",
        "Þórbjörn",
        "Þórður",
        "Þórgnýr",
        "Þórgrímur",
        "Þórhaddur",
        "Þórhalli",
        "Þórhallur",
        "Þórir",
        "Þórlaugur",
        "Þórleifur",
        "Þórlindur",
        "Þórmar",
        "Þórmundur",
        "Þóroddur",
        "Þórormur",
        "Þórólfur",
        "Þórsteinn",
        "Þórörn",
        "Þrastar",
        "Þráinn",
        "Þrándur",
        "Þróttur",
        "Þrúðmar",
        "Þrymur",
        "Þröstur",
        "Þyrnir",
        "Ægir",
        "Æsir",
        "Ævar",
        "Ævarr",
        "Ögmundur",
        "Ögri",
        "Ölnir",
        "Ölver",
        "Ölvir",
        "Öndólfur",
        "Önundur",
        "Örlaugur",
        "Örlygur",
        "Örn",
        "Örnólfur",
        "Örvar",
        "Össur",
        "Öxar",
    )
    # Icelandic female names
    first_names_female = (
        "Aagot",
        "Abela",
        "Abigael",
        "Ada",
        "Adda",
        "Addý",
        "Adela",
        "Adelía",
        "Adríana",
        "Aðalbjörg",
        "Aðalbjört",
        "Aðalborg",
        "Aðaldís",
        "Aðalfríður",
        "Aðalheiður",
        "Aðalrós",
        "Aðalsteina",
        "Aðalsteinunn",
        "Aðalveig",
        "Agata",
        "Agatha",
        "Agða",
        "Agla",
        "Agnea",
        "Agnes",
        "Agneta",
        "Alanta",
        "Alba",
        "Alberta",
        "Albína",
        "Alda",
        "Aldís",
        "Aldný",
        "Aleta",
        "Aletta",
        "Alexa",
        "Alexandra",
        "Alexandría",
        "Alexis",
        "Alexía",
        "Alfa",
        "Alfífa",
        "Alice",
        "Alida",
        "Alída",
        "Alína",
        "Alís",
        "Alísa",
        "Alla",
        "Allý",
        "Alma",
        "Alrún",
        "Alva",
        "Alvilda",
        "Amadea",
        "Amal",
        "Amalía",
        "Amanda",
        "Amelía",
        "Amilía",
        "Amíra",
        "Amy",
        "Amý",
        "Analía",
        "Anastasía",
        "Andra",
        "Andrá",
        "Andrea",
        "Anetta",
        "Angela",
        "Angelíka",
        "Anika",
        "Anita",
        "Aníka",
        "Anína",
        "Aníta",
        "Anja",
        "Ann",
        "Anna",
        "Annabella",
        "Annalísa",
        "Anne",
        "Annelí",
        "Annetta",
        "Anney",
        "Annika",
        "Annía",
        "Anný",
        "Antonía",
        "Apríl",
        "Ardís",
        "Arey",
        "Arinbjörg",
        "Aris",
        "Arisa",
        "Aría",
        "Aríanna",
        "Aríella",
        "Arín",
        "Arína",
        "Arís",
        "Armenía",
        "Arna",
        "Arnbjörg",
        "Arnborg",
        "Arndís",
        "Arney",
        "Arnfinna",
        "Arnfríður",
        "Arngerður",
        "Arngunnur",
        "Arnheiður",
        "Arnhildur",
        "Arnika",
        "Arnkatla",
        "Arnlaug",
        "Arnleif",
        "Arnlín",
        "Arnljót",
        "Arnóra",
        "Arnrós",
        "Arnrún",
        "Arnþóra",
        "Arnþrúður",
        "Asírí",
        "Askja",
        "Assa",
        "Astrid",
        "Atalía",
        "Atena",
        "Athena",
        "Atla",
        "Atlanta",
        "Auðbjörg",
        "Auðbjört",
        "Auðdís",
        "Auðlín",
        "Auðna",
        "Auðný",
        "Auðrún",
        "Auður",
        "Aurora",
        "Axelía",
        "Axelma",
        "Aþena",
        "Ágústa",
        "Ágústína",
        "Álfdís",
        "Álfey",
        "Álfgerður",
        "Álfheiður",
        "Álfhildur",
        "Álfrós",
        "Álfrún",
        "Álfsól",
        "Árbjörg",
        "Árbjört",
        "Árdís",
        "Árelía",
        "Árlaug",
        "Ármey",
        "Árna",
        "Árndís",
        "Árney",
        "Árnheiður",
        "Árnína",
        "Árný",
        "Áróra",
        "Ársól",
        "Ársæl",
        "Árún",
        "Árveig",
        "Árvök",
        "Árþóra",
        "Ása",
        "Ásbjörg",
        "Ásborg",
        "Ásdís",
        "Ásfríður",
        "Ásgerður",
        "Áshildur",
        "Áskatla",
        "Ásla",
        "Áslaug",
        "Ásleif",
        "Ásný",
        "Ásrós",
        "Ásrún",
        "Ást",
        "Ásta",
        "Ástbjörg",
        "Ástbjört",
        "Ástdís",
        "Ástfríður",
        "Ástgerður",
        "Ástheiður",
        "Ásthildur",
        "Ástríður",
        "Ástrós",
        "Ástrún",
        "Ástveig",
        "Ástþóra",
        "Ástþrúður",
        "Ásvör",
        "Baldey",
        "Baldrún",
        "Baldvina",
        "Barbara",
        "Barbára",
        "Bassí",
        "Bára",
        "Bebba",
        "Begga",
        "Belinda",
        "Bella",
        "Benedikta",
        "Bengta",
        "Benidikta",
        "Benía",
        "Beníta",
        "Benna",
        "Benney",
        "Benný",
        "Benta",
        "Bentey",
        "Bentína",
        "Bera",
        "Bergdís",
        "Bergey",
        "Bergfríður",
        "Bergheiður",
        "Berghildur",
        "Berglaug",
        "Berglind",
        "Berglín",
        "Bergljót",
        "Bergmannía",
        "Bergný",
        "Bergrán",
        "Bergrín",
        "Bergrós",
        "Bergrún",
        "Bergþóra",
        "Berit",
        "Bernódía",
        "Berta",
        "Bertha",
        "Bessí",
        "Bestla",
        "Beta",
        "Betanía",
        "Betsý",
        "Bettý",
        "Bil",
        "Birgit",
        "Birgitta",
        "Birna",
        "Birta",
        "Birtna",
        "Bíbí",
        "Bína",
        "Bjargdís",
        "Bjargey",
        "Bjargheiður",
        "Bjarghildur",
        "Bjarglind",
        "Bjarkey",
        "Bjarklind",
        "Bjarma",
        "Bjarndís",
        "Bjarney",
        "Bjarnfríður",
        "Bjarngerður",
        "Bjarnheiður",
        "Bjarnhildur",
        "Bjarnlaug",
        "Bjarnrún",
        "Bjarnveig",
        "Bjarný",
        "Bjarnþóra",
        "Bjarnþrúður",
        "Bjartey",
        "Bjartmey",
        "Björg",
        "Björgey",
        "Björgheiður",
        "Björghildur",
        "Björk",
        "Björney",
        "Björnfríður",
        "Björt",
        "Bláey",
        "Blíða",
        "Blín",
        "Blómey",
        "Blædís",
        "Blær",
        "Bobba",
        "Boga",
        "Bogdís",
        "Bogey",
        "Bogga",
        "Boghildur",
        "Borg",
        "Borgdís",
        "Borghildur",
        "Borgný",
        "Borgrún",
        "Borgþóra",
        "Botnía",
        "Bóel",
        "Bót",
        "Bóthildur",
        "Braga",
        "Braghildur",
        "Branddís",
        "Brá",
        "Brák",
        "Brigitta",
        "Brimdís",
        "Brimhildur",
        "Brimrún",
        "Brit",
        "Britt",
        "Britta",
        "Bríana",
        "Bríanna",
        "Bríet",
        "Bryndís",
        "Brynfríður",
        "Bryngerður",
        "Brynheiður",
        "Brynhildur",
        "Brynja",
        "Brynný",
        "Burkney",
        "Bylgja",
        "Camilla",
        "Carla",
        "Carmen",
        "Cecilia",
        "Cecilía",
        "Charlotta",
        "Charlotte",
        "Christina",
        "Christine",
        "Clara",
        "Daðey",
        "Daðína",
        "Dagbjörg",
        "Dagbjört",
        "Dagfríður",
        "Daggrós",
        "Dagheiður",
        "Dagmar",
        "Dagmey",
        "Dagný",
        "Dagrún",
        "Daldís",
        "Daley",
        "Dalía",
        "Dalla",
        "Dallilja",
        "Dalrós",
        "Dana",
        "Daney",
        "Danfríður",
        "Danheiður",
        "Danhildur",
        "Danía",
        "Daníela",
        "Daníella",
        "Dara",
        "Debora",
        "Debóra",
        "Dendý",
        "Didda",
        "Dilja",
        "Diljá",
        "Dimmblá",
        "Dimmey",
        "Día",
        "Díana",
        "Díanna",
        "Díma",
        "Dís",
        "Dísa",
        "Dísella",
        "Donna",
        "Doris",
        "Dorothea",
        "Dóa",
        "Dómhildur",
        "Dóra",
        "Dórey",
        "Dóris",
        "Dórothea",
        "Dórótea",
        "Dóróthea",
        "Drauma",
        "Draumey",
        "Drífa",
        "Droplaug",
        "Drótt",
        "Dröfn",
        "Dúa",
        "Dúfa",
        "Dúna",
        "Dýrborg",
        "Dýrfinna",
        "Dýrleif",
        "Dýrley",
        "Dýrunn",
        "Dæja",
        "Dögg",
        "Dögun",
        "Ebba",
        "Ebonney",
        "Edda",
        "Edel",
        "Edil",
        "Edit",
        "Edith",
        "Eðna",
        "Efemía",
        "Egedía",
        "Eggrún",
        "Egla",
        "Eiðný",
        "Eiðunn",
        "Eik",
        "Einbjörg",
        "Eindís",
        "Einey",
        "Einfríður",
        "Einhildur",
        "Einína",
        "Einrún",
        "Eir",
        "Eirdís",
        "Eirfinna",
        "Eiríka",
        "Eirný",
        "Eirún",
        "Elba",
        "Eldbjörg",
        "Eldey",
        "Eldlilja",
        "Eldrún",
        "Eleina",
        "Elektra",
        "Elena",
        "Elenborg",
        "Elfa",
        "Elfur",
        "Elina",
        "Elinborg",
        "Elisabeth",
        "Elía",
        "Elíana",
        "Elín",
        "Elína",
        "Elíná",
        "Elínbet",
        "Elínbjörg",
        "Elínbjört",
        "Elínborg",
        "Elíndís",
        "Elíngunnur",
        "Elínheiður",
        "Elínrós",
        "Elírós",
        "Elísa",
        "Elísabet",
        "Elísabeth",
        "Elka",
        "Ella",
        "Ellen",
        "Elley",
        "Ellisif",
        "Ellín",
        "Elly",
        "Ellý",
        "Elma",
        "Elna",
        "Elsa",
        "Elsabet",
        "Elsie",
        "Elsí",
        "Elsý",
        "Elva",
        "Elvi",
        "Elvíra",
        "Elvý",
        "Embla",
        "Emelía",
        "Emelíana",
        "Emelína",
        "Emeralda",
        "Emilía",
        "Emilíana",
        "Emilíanna",
        "Emilý",
        "Emma",
        "Emmý",
        "Emý",
        "Enea",
        "Eneka",
        "Engilbjört",
        "Engilráð",
        "Engilrós",
        "Engla",
        "Enika",
        "Enja",
        "Enóla",
        "Eres",
        "Erika",
        "Erin",
        "Erla",
        "Erlen",
        "Erlín",
        "Erna",
        "Esja",
        "Esmeralda",
        "Ester",
        "Esther",
        "Estiva",
        "Ethel",
        "Etna",
        "Eufemía",
        "Eva",
        "Evelyn",
        "Evey",
        "Evfemía",
        "Evgenía",
        "Evíta",
        "Evlalía",
        "Ey",
        "Eybjörg",
        "Eybjört",
        "Eydís",
        "Eyfríður",
        "Eygerður",
        "Eygló",
        "Eyhildur",
        "Eyja",
        "Eyjalín",
        "Eyleif",
        "Eylín",
        "Eyrós",
        "Eyrún",
        "Eyveig",
        "Eyvör",
        "Eyþóra",
        "Eyþrúður",
        "Fanndís",
        "Fanney",
        "Fannlaug",
        "Fanny",
        "Fanný",
        "Febrún",
        "Fema",
        "Filipía",
        "Filippa",
        "Filippía",
        "Finna",
        "Finnbjörg",
        "Finnbjörk",
        "Finnboga",
        "Finnborg",
        "Finndís",
        "Finney",
        "Finnfríður",
        "Finnlaug",
        "Finnrós",
        "Fía",
        "Fídes",
        "Fífa",
        "Fjalldís",
        "Fjóla",
        "Flóra",
        "Folda",
        "Fransiska",
        "Franziska",
        "Frán",
        "Fregn",
        "Freydís",
        "Freygerður",
        "Freyja",
        "Freylaug",
        "Freyleif",
        "Friðbjörg",
        "Friðbjört",
        "Friðborg",
        "Friðdís",
        "Friðdóra",
        "Friðey",
        "Friðfinna",
        "Friðgerður",
        "Friðjóna",
        "Friðlaug",
        "Friðleif",
        "Friðlín",
        "Friðmey",
        "Friðný",
        "Friðrika",
        "Friðrikka",
        "Friðrós",
        "Friðrún",
        "Friðsemd",
        "Friðveig",
        "Friðþóra",
        "Frigg",
        "Fríða",
        "Fríður",
        "Frostrós",
        "Fróðný",
        "Fura",
        "Fönn",
        "Gabríela",
        "Gabríella",
        "Gauja",
        "Gauthildur",
        "Gefjun",
        "Gefn",
        "Geira",
        "Geirbjörg",
        "Geirdís",
        "Geirfinna",
        "Geirfríður",
        "Geirhildur",
        "Geirlaug",
        "Geirlöð",
        "Geirný",
        "Geirríður",
        "Geirrún",
        "Geirþrúður",
        "Georgía",
        "Gerða",
        "Gerður",
        "Gestheiður",
        "Gestný",
        "Gestrún",
        "Gillý",
        "Gilslaug",
        "Gissunn",
        "Gía",
        "Gígja",
        "Gísela",
        "Gísla",
        "Gísley",
        "Gíslína",
        "Gíslný",
        "Gíslrún",
        "Gíslunn",
        "Gíta",
        "Gjaflaug",
        "Gloría",
        "Gló",
        "Glóa",
        "Glóbjört",
        "Glódís",
        "Glóð",
        "Glóey",
        "Gná",
        "Góa",
        "Gógó",
        "Grein",
        "Gret",
        "Greta",
        "Grélöð",
        "Grét",
        "Gréta",
        "Gríma",
        "Grímey",
        "Grímheiður",
        "Grímhildur",
        "Gróa",
        "Guðbjörg",
        "Guðbjört",
        "Guðborg",
        "Guðdís",
        "Guðfinna",
        "Guðfríður",
        "Guðjóna",
        "Guðlaug",
        "Guðleif",
        "Guðlín",
        "Guðmey",
        "Guðmunda",
        "Guðmundína",
        "Guðný",
        "Guðríður",
        "Guðrún",
        "Guðsteina",
        "Guðveig",
        "Gullbrá",
        "Gullveig",
        "Gullý",
        "Gumma",
        "Gunnbjörg",
        "Gunnbjört",
        "Gunnborg",
        "Gunndís",
        "Gunndóra",
        "Gunnella",
        "Gunnfinna",
        "Gunnfríður",
        "Gunnharða",
        "Gunnheiður",
        "Gunnhildur",
        "Gunnjóna",
        "Gunnlaug",
        "Gunnleif",
        "Gunnlöð",
        "Gunnrún",
        "Gunnur",
        "Gunnveig",
        "Gunnvör",
        "Gunný",
        "Gunnþóra",
        "Gunnþórunn",
        "Gurrý",
        "Gúa",
        "Gyða",
        "Gyðja",
        "Gyðríður",
        "Gytta",
        "Gæfa",
        "Gæflaug",
        "Hadda",
        "Haddý",
        "Hafbjörg",
        "Hafborg",
        "Hafdís",
        "Hafey",
        "Hafliða",
        "Haflína",
        "Hafný",
        "Hafrós",
        "Hafrún",
        "Hafsteina",
        "Hafþóra",
        "Halla",
        "Hallbera",
        "Hallbjörg",
        "Hallborg",
        "Halldís",
        "Halldóra",
        "Halley",
        "Hallfríður",
        "Hallgerður",
        "Hallgunnur",
        "Hallkatla",
        "Hallný",
        "Hallrún",
        "Hallveig",
        "Hallvör",
        "Hanna",
        "Hanney",
        "Hansa",
        "Hansína",
        "Harpa",
        "Hauður",
        "Hákonía",
        "Heba",
        "Hedda",
        "Hedí",
        "Heiða",
        "Heiðbjörg",
        "Heiðbjörk",
        "Heiðbjört",
        "Heiðbrá",
        "Heiðdís",
        "Heiðlaug",
        "Heiðlóa",
        "Heiðný",
        "Heiðrós",
        "Heiðrún",
        "Heiður",
        "Heiðveig",
        "Hekla",
        "Helen",
        "Helena",
        "Helga",
        "Hella",
        "Helma",
        "Hendrikka",
        "Henný",
        "Henrietta",
        "Henrika",
        "Henríetta",
        "Hera",
        "Herbjörg",
        "Herbjört",
        "Herborg",
        "Herdís",
        "Herfríður",
        "Hergerður",
        "Herlaug",
        "Hermína",
        "Hersilía",
        "Herta",
        "Hertha",
        "Hervör",
        "Herþrúður",
        "Hilda",
        "Hildegard",
        "Hildibjörg",
        "Hildigerður",
        "Hildigunnur",
        "Hildiríður",
        "Hildisif",
        "Hildur",
        "Hilma",
        "Himinbjörg",
        "Hind",
        "Hinrika",
        "Hinrikka",
        "Hjalta",
        "Hjaltey",
        "Hjálmdís",
        "Hjálmey",
        "Hjálmfríður",
        "Hjálmgerður",
        "Hjálmrós",
        "Hjálmrún",
        "Hjálmveig",
        "Hjördís",
        "Hjörfríður",
        "Hjörleif",
        "Hjörný",
        "Hjörtfríður",
        "Hlaðgerður",
        "Hlédís",
        "Hlíf",
        "Hlín",
        "Hlökk",
        "Hólmbjörg",
        "Hólmdís",
        "Hólmfríður",
        "Hrafna",
        "Hrafnborg",
        "Hrafndís",
        "Hrafney",
        "Hrafngerður",
        "Hrafnheiður",
        "Hrafnhildur",
        "Hrafnkatla",
        "Hrafnlaug",
        "Hrafntinna",
        "Hraundís",
        "Hrefna",
        "Hreindís",
        "Hróðný",
        "Hrólfdís",
        "Hrund",
        "Hrönn",
        "Hugbjörg",
        "Hugbjört",
        "Hugborg",
        "Hugdís",
        "Hugljúf",
        "Hugrún",
        "Huld",
        "Hulda",
        "Huldís",
        "Huldrún",
        "Húnbjörg",
        "Húndís",
        "Húngerður",
        "Hvönn",
        "Hödd",
        "Högna",
        "Hörn",
        "Ida",
        "Idda",
        "Iða",
        "Iðunn",
        "Ilmur",
        "Immý",
        "Ina",
        "Inda",
        "India",
        "Indiana",
        "Indía",
        "Indíana",
        "Indíra",
        "Indra",
        "Inga",
        "Ingdís",
        "Ingeborg",
        "Inger",
        "Ingey",
        "Ingheiður",
        "Inghildur",
        "Ingibjörg",
        "Ingibjört",
        "Ingiborg",
        "Ingifinna",
        "Ingifríður",
        "Ingigerður",
        "Ingilaug",
        "Ingileif",
        "Ingilín",
        "Ingimaría",
        "Ingimunda",
        "Ingiríður",
        "Ingirós",
        "Ingisól",
        "Ingiveig",
        "Ingrid",
        "Ingrún",
        "Ingunn",
        "Ingveldur",
        "Inna",
        "Irena",
        "Irene",
        "Irja",
        "Irma",
        "Irmý",
        "Irpa",
        "Isabel",
        "Isabella",
        "Ída",
        "Íma",
        "Ína",
        "Ír",
        "Íren",
        "Írena",
        "Íris",
        "Írunn",
        "Ísabel",
        "Ísabella",
        "Ísadóra",
        "Ísafold",
        "Ísalind",
        "Ísbjörg",
        "Ísdís",
        "Ísey",
        "Ísfold",
        "Ísgerður",
        "Íshildur",
        "Ísis",
        "Íslaug",
        "Ísleif",
        "Ísmey",
        "Ísold",
        "Ísól",
        "Ísrún",
        "Íssól",
        "Ísveig",
        "Íunn",
        "Íva",
        "Jakobína",
        "Jana",
        "Jane",
        "Janetta",
        "Jannika",
        "Jara",
        "Jarún",
        "Jarþrúður",
        "Jasmín",
        "Járnbrá",
        "Járngerður",
        "Jenetta",
        "Jenna",
        "Jenný",
        "Jensína",
        "Jessý",
        "Jovina",
        "Jóa",
        "Jóanna",
        "Jódís",
        "Jófríður",
        "Jóhanna",
        "Jólín",
        "Jóna",
        "Jónanna",
        "Jónasína",
        "Jónbjörg",
        "Jónbjört",
        "Jóndís",
        "Jóndóra",
        "Jóney",
        "Jónfríður",
        "Jóngerð",
        "Jónheiður",
        "Jónhildur",
        "Jóninna",
        "Jónída",
        "Jónína",
        "Jónný",
        "Jóný",
        "Jóra",
        "Jóríður",
        "Jórlaug",
        "Jórunn",
        "Jósebína",
        "Jósefín",
        "Jósefína",
        "Judith",
        "Júdea",
        "Júdit",
        "Júlía",
        "Júlíana",
        "Júlíanna",
        "Júlíetta",
        "Júlírós",
        "Júnía",
        "Júníana",
        "Jökla",
        "Jökulrós",
        "Jörgína",
        "Kaðlín",
        "Kaja",
        "Kalla",
        "Kamilla",
        "Kamí",
        "Kamma",
        "Kapitola",
        "Kapítóla",
        "Kara",
        "Karen",
        "Karin",
        "Karitas",
        "Karí",
        "Karín",
        "Karína",
        "Karítas",
        "Karla",
        "Karlinna",
        "Karlína",
        "Karlotta",
        "Karolína",
        "Karó",
        "Karólín",
        "Karólína",
        "Kassandra",
        "Kata",
        "Katarína",
        "Katerína",
        "Katharina",
        "Kathinka",
        "Katinka",
        "Katla",
        "Katrín",
        "Katrína",
        "Katý",
        "Kára",
        "Kellý",
        "Kendra",
        "Ketilbjörg",
        "Ketilfríður",
        "Ketilríður",
        "Kiddý",
        "Kira",
        "Kirsten",
        "Kirstín",
        "Kittý",
        "Kjalvör",
        "Klara",
        "Kládía",
        "Klementína",
        "Kleópatra",
        "Kolbjörg",
        "Kolbrá",
        "Kolbrún",
        "Koldís",
        "Kolfinna",
        "Kolfreyja",
        "Kolgríma",
        "Kolka",
        "Konkordía",
        "Konný",
        "Korka",
        "Kormlöð",
        "Kornelía",
        "Kókó",
        "Krista",
        "Kristbjörg",
        "Kristborg",
        "Kristel",
        "Kristensa",
        "Kristey",
        "Kristfríður",
        "Kristgerður",
        "Kristin",
        "Kristine",
        "Kristíana",
        "Kristíanna",
        "Kristín",
        "Kristína",
        "Kristjana",
        "Kristjóna",
        "Kristlaug",
        "Kristlind",
        "Kristlín",
        "Kristný",
        "Kristólína",
        "Kristrós",
        "Kristrún",
        "Kristveig",
        "Kristvina",
        "Kristþóra",
        "Kría",
        "Kæja",
        "Laila",
        "Laíla",
        "Lana",
        "Lara",
        "Laufey",
        "Laufheiður",
        "Laufhildur",
        "Lauga",
        "Laugey",
        "Laugheiður",
        "Lára",
        "Lárensína",
        "Láretta",
        "Lárey",
        "Lea",
        "Leikný",
        "Leila",
        "Lena",
        "Leonóra",
        "Leóna",
        "Leónóra",
        "Lilja",
        "Liljá",
        "Liljurós",
        "Lill",
        "Lilla",
        "Lillian",
        "Lillý",
        "Lily",
        "Lilý",
        "Lind",
        "Linda",
        "Linddís",
        "Lingný",
        "Lisbeth",
        "Listalín",
        "Liv",
        "Líba",
        "Líf",
        "Lífdís",
        "Lín",
        "Lína",
        "Línbjörg",
        "Líndís",
        "Líneik",
        "Líney",
        "Línhildur",
        "Lísa",
        "Lísabet",
        "Lísandra",
        "Lísbet",
        "Lísebet",
        "Lív",
        "Ljósbjörg",
        "Ljósbrá",
        "Ljótunn",
        "Lofn",
        "Loftveig",
        "Logey",
        "Lokbrá",
        "Lotta",
        "Louisa",
        "Lousie",
        "Lovísa",
        "Lóa",
        "Lóreley",
        "Lukka",
        "Lúcía",
        "Lúðvíka",
        "Lúísa",
        "Lúna",
        "Lúsinda",
        "Lúsía",
        "Lúvísa",
        "Lydia",
        "Lydía",
        "Lyngheiður",
        "Lýdía",
        "Læla",
        "Maddý",
        "Magda",
        "Magdalena",
        "Magðalena",
        "Magga",
        "Maggey",
        "Maggý",
        "Magna",
        "Magndís",
        "Magnea",
        "Magnes",
        "Magney",
        "Magnfríður",
        "Magnheiður",
        "Magnhildur",
        "Magnúsína",
        "Magný",
        "Magnþóra",
        "Maía",
        "Maídís",
        "Maísól",
        "Maj",
        "Maja",
        "Malen",
        "Malena",
        "Malía",
        "Malín",
        "Malla",
        "Manda",
        "Manúela",
        "Mara",
        "Mardís",
        "Marela",
        "Marella",
        "Maren",
        "Marey",
        "Marfríður",
        "Margit",
        "Margot",
        "Margret",
        "Margrét",
        "Margrjet",
        "Margunnur",
        "Marheiður",
        "Maria",
        "Marie",
        "Marikó",
        "Marinella",
        "Marit",
        "Marí",
        "María",
        "Maríam",
        "Marían",
        "Maríana",
        "Maríanna",
        "Marín",
        "Marína",
        "Marínella",
        "Maríon",
        "Marísa",
        "Marísól",
        "Marít",
        "Maríuerla",
        "Marja",
        "Markrún",
        "Marlaug",
        "Marlena",
        "Marlín",
        "Marlís",
        "Marólína",
        "Marsa",
        "Marselía",
        "Marselína",
        "Marsibil",
        "Marsilía",
        "Marsý",
        "Marta",
        "Martha",
        "Martína",
        "Mary",
        "Marý",
        "Matta",
        "Mattea",
        "Matthea",
        "Matthilda",
        "Matthildur",
        "Matthía",
        "Mattíana",
        "Mattína",
        "Mattý",
        "Maxima",
        "Mábil",
        "Málfríður",
        "Málhildur",
        "Málmfríður",
        "Mánadís",
        "Máney",
        "Mára",
        "Meda",
        "Mekkin",
        "Mekkín",
        "Melinda",
        "Melissa",
        "Melkorka",
        "Melrós",
        "Messíana",
        "Metta",
        "Mey",
        "Mikaela",
        "Mikaelína",
        "Mikkalína",
        "Milda",
        "Mildríður",
        "Milla",
        "Millý",
        "Minerva",
        "Minna",
        "Minney",
        "Minný",
        "Miriam",
        "Mirja",
        "Mirjam",
        "Mirra",
        "Mist",
        "Mía",
        "Mínerva",
        "Míra",
        "Míranda",
        "Mítra",
        "Mjaðveig",
        "Mjalldís",
        "Mjallhvít",
        "Mjöll",
        "Mona",
        "Monika",
        "Módís",
        "Móeiður",
        "Móey",
        "Móheiður",
        "Móna",
        "Mónika",
        "Móníka",
        "Munda",
        "Mundheiður",
        "Mundhildur",
        "Mundína",
        "Myrra",
        "Mýr",
        "Mýra",
        "Mýrún",
        "Mörk",
        "Nadia",
        "Nadía",
        "Nadja",
        "Nana",
        "Nanna",
        "Nanný",
        "Nansý",
        "Naomí",
        "Naómí",
        "Natalie",
        "Natalía",
        "Náttsól",
        "Nella",
        "Nellý",
        "Nenna",
        "Nicole",
        "Niðbjörg",
        "Nikíta",
        "Nikoletta",
        "Nikólína",
        "Ninja",
        "Ninna",
        "Nína",
        "Níní",
        "Njála",
        "Njóla",
        "Norma",
        "Nóa",
        "Nóra",
        "Nótt",
        "Nýbjörg",
        "Odda",
        "Oddbjörg",
        "Oddfreyja",
        "Oddfríður",
        "Oddgerður",
        "Oddhildur",
        "Oddlaug",
        "Oddleif",
        "Oddný",
        "Oddrún",
        "Oddveig",
        "Oddvör",
        "Oktavía",
        "Októvía",
        "Olga",
        "Ollý",
        "Ora",
        "Orka",
        "Ormheiður",
        "Ormhildur",
        "Otkatla",
        "Otta",
        "Óda",
        "Ófelía",
        "Óla",
        "Ólafía",
        "Ólafína",
        "Ólavía",
        "Ólivía",
        "Ólína",
        "Ólöf",
        "Ósa",
        "Ósk",
        "Ótta",
        "Pamela",
        "París",
        "Patricia",
        "Patrisía",
        "Pála",
        "Páldís",
        "Páley",
        "Pálfríður",
        "Pálhanna",
        "Pálheiður",
        "Pálhildur",
        "Pálín",
        "Pálína",
        "Pálmey",
        "Pálmfríður",
        "Pálrún",
        "Perla",
        "Peta",
        "Petra",
        "Petrea",
        "Petrína",
        "Petronella",
        "Petrónella",
        "Petrós",
        "Petrún",
        "Petrúnella",
        "Pétrína",
        "Pétrún",
        "Pía",
        "Polly",
        "Pollý",
        "Pría",
        "Rafney",
        "Rafnhildur",
        "Ragna",
        "Ragnbjörg",
        "Ragney",
        "Ragnfríður",
        "Ragnheiður",
        "Ragnhildur",
        "Rakel",
        "Ramóna",
        "Randalín",
        "Randíður",
        "Randý",
        "Ranka",
        "Rannva",
        "Rannveig",
        "Ráðhildur",
        "Rán",
        "Rebekka",
        "Reginbjörg",
        "Regína",
        "Rein",
        "Renata",
        "Reyn",
        "Reyndís",
        "Reynheiður",
        "Reynhildur",
        "Rikka",
        "Ripley",
        "Rita",
        "Ríkey",
        "Rín",
        "Ríta",
        "Ronja",
        "Rorí",
        "Roxanna",
        "Róberta",
        "Róbjörg",
        "Rós",
        "Rósa",
        "Rósalind",
        "Rósanna",
        "Rósbjörg",
        "Rósborg",
        "Róselía",
        "Rósey",
        "Rósfríður",
        "Róshildur",
        "Rósinkara",
        "Rósinkransa",
        "Róska",
        "Róslaug",
        "Róslind",
        "Róslinda",
        "Róslín",
        "Rósmary",
        "Rósmarý",
        "Rósmunda",
        "Rósný",
        "Runný",
        "Rut",
        "Ruth",
        "Rúbý",
        "Rún",
        "Rúna",
        "Rúndís",
        "Rúnhildur",
        "Rúrí",
        "Röfn",
        "Rögn",
        "Röskva",
        "Sabína",
        "Sabrína",
        "Saga",
        "Salbjörg",
        "Saldís",
        "Salgerður",
        "Salín",
        "Salína",
        "Salka",
        "Salma",
        "Salný",
        "Salome",
        "Salóme",
        "Salvör",
        "Sandra",
        "Sanna",
        "Santía",
        "Sara",
        "Sarína",
        "Sefanía",
        "Selja",
        "Selka",
        "Selma",
        "Senía",
        "Septíma",
        "Sera",
        "Serena",
        "Seselía",
        "Sesilía",
        "Sesselía",
        "Sesselja",
        "Sessilía",
        "Sif",
        "Sigdís",
        "Sigdóra",
        "Sigfríð",
        "Sigfríður",
        "Sigga",
        "Siggerður",
        "Sigmunda",
        "Signa",
        "Signhildur",
        "Signý",
        "Sigríður",
        "Sigrún",
        "Sigurást",
        "Sigurásta",
        "Sigurbára",
        "Sigurbirna",
        "Sigurbjörg",
        "Sigurbjört",
        "Sigurborg",
        "Sigurdís",
        "Sigurdóra",
        "Sigurdríf",
        "Sigurdrífa",
        "Sigurða",
        "Sigurey",
        "Sigurfinna",
        "Sigurfljóð",
        "Sigurgeira",
        "Sigurhanna",
        "Sigurhelga",
        "Sigurhildur",
        "Sigurjóna",
        "Sigurlaug",
        "Sigurleif",
        "Sigurlilja",
        "Sigurlinn",
        "Sigurlín",
        "Sigurlína",
        "Sigurmunda",
        "Sigurnanna",
        "Sigurósk",
        "Sigurrós",
        "Sigursteina",
        "Sigurunn",
        "Sigurveig",
        "Sigurvina",
        "Sigurþóra",
        "Sigyn",
        "Sigþóra",
        "Sigþrúður",
        "Silfa",
        "Silfá",
        "Silfrún",
        "Silja",
        "Silka",
        "Silla",
        "Silva",
        "Silvana",
        "Silvía",
        "Sirra",
        "Sirrý",
        "Siv",
        "Sía",
        "Símonía",
        "Sísí",
        "Síta",
        "Sjöfn",
        "Skarpheiður",
        "Skugga",
        "Skuld",
        "Skúla",
        "Skúlína",
        "Snjáfríður",
        "Snjáka",
        "Snjófríður",
        "Snjólaug",
        "Snorra",
        "Snót",
        "Snæbjörg",
        "Snæbjört",
        "Snæborg",
        "Snæbrá",
        "Snædís",
        "Snæfríður",
        "Snælaug",
        "Snærós",
        "Snærún",
        "Soffía",
        "Sofie",
        "Sofía",
        "Solveig",
        "Sonja",
        "Sonný",
        "Sophia",
        "Sophie",
        "Sól",
        "Sóla",
        "Sólbjörg",
        "Sólbjört",
        "Sólborg",
        "Sólbrá",
        "Sólbrún",
        "Sóldís",
        "Sóldögg",
        "Sóley",
        "Sólfríður",
        "Sólgerður",
        "Sólhildur",
        "Sólín",
        "Sólkatla",
        "Sóllilja",
        "Sólný",
        "Sólrós",
        "Sólrún",
        "Sólveig",
        "Sólvör",
        "Sónata",
        "Stefana",
        "Stefanía",
        "Stefánný",
        "Steina",
        "Steinbjörg",
        "Steinborg",
        "Steindís",
        "Steindóra",
        "Steiney",
        "Steinfríður",
        "Steingerður",
        "Steinhildur",
        "Steinlaug",
        "Steinrós",
        "Steinrún",
        "Steinunn",
        "Steinvör",
        "Steinþóra",
        "Stella",
        "Stígheiður",
        "Stígrún",
        "Stína",
        "Stjarna",
        "Styrgerður",
        "Sumarlína",
        "Sumarrós",
        "Sunna",
        "Sunnefa",
        "Sunneva",
        "Sunniva",
        "Sunníva",
        "Susan",
        "Súla",
        "Súsan",
        "Súsanna",
        "Svafa",
        "Svala",
        "Svalrún",
        "Svana",
        "Svanbjörg",
        "Svanbjört",
        "Svanborg",
        "Svandís",
        "Svaney",
        "Svanfríður",
        "Svanheiður",
        "Svanhildur",
        "Svanhvít",
        "Svanlaug",
        "Svanrós",
        "Svanþrúður",
        "Svava",
        "Svea",
        "Sveina",
        "Sveinbjörg",
        "Sveinborg",
        "Sveindís",
        "Sveiney",
        "Sveinfríður",
        "Sveingerður",
        "Sveinhildur",
        "Sveinlaug",
        "Sveinrós",
        "Sveinrún",
        "Sveinsína",
        "Sveinveig",
        "Sylgja",
        "Sylva",
        "Sylvía",
        "Sæbjörg",
        "Sæbjört",
        "Sæborg",
        "Sædís",
        "Sæfinna",
        "Sæfríður",
        "Sæhildur",
        "Sælaug",
        "Sæmunda",
        "Sæný",
        "Særós",
        "Særún",
        "Sæsól",
        "Sæunn",
        "Sævör",
        "Sölva",
        "Sölvey",
        "Sölvína",
        "Tala",
        "Talía",
        "Tamar",
        "Tamara",
        "Tanía",
        "Tanja",
        "Tanya",
        "Tanya",
        "Tara",
        "Tea",
        "Teitný",
        "Tekla",
        "Telma",
        "Tera",
        "Teresa",
        "Teresía",
        "Thea",
        "Thelma",
        "Theodóra",
        "Theódóra",
        "Theresa",
        "Tindra",
        "Tinna",
        "Tirsa",
        "Tía",
        "Tíbrá",
        "Tína",
        "Todda",
        "Torbjörg",
        "Torfey",
        "Torfheiður",
        "Torfhildur",
        "Tóbý",
        "Tóka",
        "Tóta",
        "Tristana",
        "Trú",
        "Tryggva",
        "Tryggvína",
        "Týra",
        "Ugla",
        "Una",
        "Undína",
        "Unna",
        "Unnbjörg",
        "Unndís",
        "Unnur",
        "Urður",
        "Úa",
        "Úlfa",
        "Úlfdís",
        "Úlfey",
        "Úlfheiður",
        "Úlfhildur",
        "Úlfrún",
        "Úlla",
        "Úna",
        "Úndína",
        "Úranía",
        "Úrsúla",
        "Vagna",
        "Vagnbjörg",
        "Vagnfríður",
        "Vaka",
        "Vala",
        "Valbjörg",
        "Valbjörk",
        "Valbjört",
        "Valborg",
        "Valdheiður",
        "Valdís",
        "Valentína",
        "Valería",
        "Valey",
        "Valfríður",
        "Valgerða",
        "Valgerður",
        "Valhildur",
        "Valka",
        "Vallý",
        "Valný",
        "Valrós",
        "Valrún",
        "Valva",
        "Valý",
        "Valþrúður",
        "Vanda",
        "Vár",
        "Veig",
        "Veiga",
        "Venus",
        "Vera",
        "Veronika",
        "Verónika",
        "Veróníka",
        "Vetrarrós",
        "Vébjörg",
        "Védís",
        "Végerður",
        "Vélaug",
        "Véný",
        "Vibeka",
        "Victoría",
        "Viðja",
        "Vigdís",
        "Vigný",
        "Viktoria",
        "Viktoría",
        "Vilborg",
        "Vildís",
        "Vilfríður",
        "Vilgerður",
        "Vilhelmína",
        "Villa",
        "Villimey",
        "Vilma",
        "Vilný",
        "Vinbjörg",
        "Vinný",
        "Vinsý",
        "Virginía",
        "Víbekka",
        "Víf",
        "Vígdögg",
        "Víggunnur",
        "Víóla",
        "Víóletta",
        "Vísa",
        "Von",
        "Von",
        "Voney",
        "Vordís",
        "Ylfa",
        "Ylfur",
        "Ylja",
        "Ylva",
        "Ynja",
        "Yrja",
        "Yrsa",
        "Ýja",
        "Ýma",
        "Ýr",
        "Ýrr",
        "Þalía",
        "Þeba",
        "Þeódís",
        "Þeódóra",
        "Þjóðbjörg",
        "Þjóðhildur",
        "Þoka",
        "Þorbjörg",
        "Þorfinna",
        "Þorgerður",
        "Þorgríma",
        "Þorkatla",
        "Þorlaug",
        "Þorleif",
        "Þorsteina",
        "Þorstína",
        "Þóra",
        "Þóranna",
        "Þórarna",
        "Þórbjörg",
        "Þórdís",
        "Þórða",
        "Þórelfa",
        "Þórelfur",
        "Þórey",
        "Þórfríður",
        "Þórgunna",
        "Þórgunnur",
        "Þórhalla",
        "Þórhanna",
        "Þórheiður",
        "Þórhildur",
        "Þórkatla",
        "Þórlaug",
        "Þórleif",
        "Þórný",
        "Þórodda",
        "Þórsteina",
        "Þórsteinunn",
        "Þórstína",
        "Þórunn",
        "Þórveig",
        "Þórvör",
        "Þrá",
        "Þrúða",
        "Þrúður",
        "Þula",
        "Þura",
        "Þurí",
        "Þuríður",
        "Þurý",
        "Þúfa",
        "Þyri",
        "Þyrí",
        "Þöll",
        "Ægileif",
        "Æsa",
        "Æsgerður",
        "Ögmunda",
        "Ögn",
        "Ölrún",
        "Ölveig",
        "Örbrún",
        "Örk",
        "Ösp",
    )

    first_names = first_names_male + first_names_female

    # prepare a temp list of last names for further processing
    last_names_without_suffix = []
    for fnm in first_names_male:
        if fnm.endswith("ur"):
            fnm = fnm[:-2]
        if not fnm.endswith("s"):
            fnm = fnm + "s"
        last_names_without_suffix.append(fnm)
    last_names_without_suffix = tuple(last_names_without_suffix)

    # Icelandic male last names
    def last_name_male(self) -> str:
        return self.random_element(self.last_names_without_suffix) + "son"

    # Icelandic female last names
    def last_name_female(self) -> str:
        return self.random_element(self.last_names_without_suffix) + "dóttir"

    # Icelandic male and female last names
    def last_name(self) -> str:
        get_random_last_name = self.random_element((self.last_name_male, self.last_name_female))
        return get_random_last_name()

    # Icelandic middle names
    middle_names = (
        "Aðaldal",
        "Aldan",
        "Arnberg",
        "Arnfjörð",
        "Austan",
        "Austdal",
        "Austfjörð",
        "Áss",
        "Bakkdal",
        "Bakkmann",
        "Bald",
        "Ben",
        "Bergholt",
        "Bergland",
        "Bíldsfells",
        "Bjarg",
        "Bjarndal",
        "Bjarnfjörð",
        "Bláfeld",
        "Blómkvist",
        "Borgdal",
        "Brekkmann",
        "Brim",
        "Brúnsteð",
        "Dalhoff",
        "Dan",
        "Diljan",
        "Ektavon",
        "Eldberg",
        "Elísberg",
        "Elvan",
        "Espólín",
        "Eyhlíð",
        "Eyvík",
        "Falk",
        "Finndal",
        "Fossberg",
        "Freydal",
        "Friðhólm",
        "Giljan",
        "Gilsfjörð",
        "Gnarr",
        "Gnurr",
        "Grendal",
        "Grindvík",
        "Gull",
        "Haffjörð",
        "Hafnes",
        "Hafnfjörð",
        "Har",
        "Heimdal",
        "Heimsberg",
        "Helgfell",
        "Herberg",
        "Hildiberg",
        "Hjaltdal",
        "Hlíðkvist",
        "Hnappdal",
        "Hnífsdal",
        "Hofland",
        "Hofteig",
        "Hornfjörð",
        "Hólmberg",
        "Hrafnan",
        "Hrafndal",
        "Hraunberg",
        "Hreinberg",
        "Hreindal",
        "Hrútfjörð",
        "Hvammdal",
        "Hvítfeld",
        "Höfðdal",
        "Hörðdal",
        "Íshólm",
        "Júl",
        "Kjarrval",
        "Knaran",
        "Knarran",
        "Krossdal",
        "Laufkvist",
        "Laufland",
        "Laugdal",
        "Laxfoss",
        "Liljan",
        "Linddal",
        "Línberg",
        "Ljós",
        "Loðmfjörð",
        "Lyngberg",
        "Magdal",
        "Magg",
        "Matt",
        "Miðdal",
        "Miðvík",
        "Mjófjörð",
        "Móberg",
        "Mýrmann",
        "Nesmann",
        "Norðland",
        "Núpdal",
        "Ólfjörð",
        "Ósland",
        "Ósmann",
        "Reginbald",
        "Reykfell",
        "Reykfjörð",
        "Reynholt",
        "Salberg",
        "Sandhólm",
        "Seljan",
        "Sigurhólm",
        "Skagalín",
        "Skíðdal",
        "Snæberg",
        "Snædahl",
        "Sólan",
        "Stardal",
        "Stein",
        "Steinbekk",
        "Steinberg",
        "Storm",
        "Straumberg",
        "Svanhild",
        "Svarfdal",
        "Sædal",
        "Val",
        "Valagils",
        "Vald",
        "Varmdal",
        "Vatnsfjörð",
        "Vattar",
        "Vattnes",
        "Viðfjörð",
        "Vídalín",
        "Víking",
        "Vopnfjörð",
        "Yngling",
        "Þor",
        "Önfjörð",
        "Örbekk",
        "Öxdal",
        "Öxndal",
    )

    def middle_name(self) -> str:
        return self.random_element(self.middle_names)



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    """
    A Faker provider for generating fake Zulu names in South Africa.
    """

    formats = (
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}} {{last_name_male}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}} {{last_name_female}}",
        "{{prefix_male}} {{first_name_male}} {{last_name_male}}",
        "{{prefix_female}} {{first_name_female}} {{last_name_female}}",
        "{{prefix_male}} {{first_name_male}} {{last_name_male}}",
        "{{prefix_female}} {{first_name_female}} {{last_name_female}}",
    )

    # first names sourced from:
    # 1. https://github.com/faker-js/faker/blob/next/src/locales/yo_NG/person/last_name.ts
    # 2. https://github.com/faker-js/faker/blob/next/src/locales/yo_NG/person/male_first_name.ts

    first_names_male = (
        "Abayomi",
        "Abiodun",
        "Abiona",
        "Adebiyi",
        "Adebowale",
        "Adedayo",
        "Adedeji",
        "Adekitan",
        "Adekola",
        "Adekunle",
        "Adeleke",
        "Adeniyi",
        "Adeolu",
        "Adeoti",
        "Aderopo",
        "Adeshina",
        "Adesoji",
        "Adetayo",
        "Adeyi",
        "Adigun",
        "Afolarin",
        "Ajala",
        "Ajani",
        "Akanmu",
        "Akinkunmi",
        "Akinlabi",
        "Akinwale",
        "Alade",
        "Alamu",
        "Anjolaoluwa",
        "Ayinde",
        "Ayodeji",
        "Ayodele",
        "Babasola",
        "Babatunji",
        "Babawale",
        "Damife",
        "Demilade",
        "Durodola",
        "Ekundayo",
        "Esupofo",
        "Folu",
        "Gbadebo",
        "Gbolahan",
        "Gbowoade",
        "Ibidapo",
        "Ige",
        "Ikeoluwa",
        "Inioluwa",
        "Iseoluwa",
        "Ishola",
        "Juwon",
        "Keji",
        "Kolawole",
        "Korede",
        "Leke",
        "Lere",
        "Niyilolawa",
        "Oba",
        "ObaniJesu",
        "Ogooluwa",
        "Oke",
        "Oladare",
        "Oladimeji",
        "Olakunle",
        "Olanrewaju",
        "Olansile",
        "Olumorotimi",
        "Oluwafemi",
        "Oluwagbemiga",
        "Oluwamumibori",
        "Oluwamuyiwa",
        "Oluwasanmi",
        "Oluwasegun",
        "Oluwole",
        "Omobobola",
        "Omotayo",
        "Osunleke",
        "Seye",
        "Shekoni",
        "Sijuade",
        "Tade",
        "Temidayo",
        "Toki",
        "Tokunbo",
        "Tomori",
    )
    first_names_female = (
        "Aanuoluwapo",
        "Abebi",
        "Abeni",
        "Abosede",
        "Adebukola",
        "Adenike",
        "Adepeju",
        "Adesewa",
        "Adesua",
        "Adetoke",
        "Adetoun",
        "Adunni",
        "Ajoke",
        "Amoke",
        "Amope",
        "Arike",
        "Arinola",
        "Asake",
        "Atinuke",
        "Awero",
        "Ayinke",
        "Ayoka",
        "Bolatito",
        "Boluwatife",
        "Bunmi",
        "Doyinsola",
        "Eniola",
        "Ewatomi",
        "Fadekemi",
        "Faderera",
        "Fehintola",
        "Fibikemi",
        "Fikayomi",
        "Folashade",
        "Ibironke",
        "Iretioluwa",
        "Iyabode",
        "Iyadunni",
        "Kikelomo",
        "Modupe",
        "Mofifoluwa",
        "Mojisola",
        "Mojisoluwa",
        "Moradeke",
        "Morayo",
        "Morenike",
        "Morolake",
        "Mosinmileoluwa",
        "Mosunmola",
        "Motunrayo",
        "Moyosore",
        "Ninioluwa",
        "Olajumoke",
        "Olasunmbo",
        "Ololade",
        "Olufunke",
        "Olufunmilayo",
        "Oluwakemi",
        "Omobolanle",
        "Omodunni",
        "Omolabake",
        "Omolara",
        "Omosalewa",
        "Omotara",
        "Omotola",
        "Omotoun",
        "Omowumi",
        "Oreofe",
        "Oyenike",
        "Oyindasola",
        "Radeke",
        "Ronke",
        "Segilola",
        "Similoluwa",
        "Simisola",
        "Sowande",
        "Subomi",
        "Titilayo",
        "Tolulope",
        "Toluwanimi",
        "Wuraola",
        "Yejide",
        "Yetunde",
        "Yewande",
    )

    first_names = first_names_male + first_names_female

    # last names sourced from :
    # 1. https://github.com/faker-js/faker/blob/next/src/locales/yo_NG/person/last_name.ts
    last_names_male = (
        "Adebisi",
        "Adegbite",
        "Adegoke",
        "Adekunle",
        "Adelakun",
        "Adeleke",
        "Adelusi",
        "Ademiluyi",
        "Aderibigbe",
        "Aderogba",
        "Adesiyan",
        "Adeyemo",
        "Adisa",
        "Afolabi",
        "Afolayan",
        "Afonja",
        "Ajao",
        "Ajayi",
        "Ajewole",
        "Akinrinola",
        "Alabi",
        "Aloba",
        "Awodiran",
        "Awolowo",
        "Ayandokun",
        "Ayoola",
        "Babtunde",
        "Bakare",
        "Balogun",
        "Bamidele",
        "Bamiloye",
        "Edun",
        "Fadipe",
        "Fagunwa",
        "Fajimi",
        "Falabi",
        "Faleti",
        "Faloye",
        "Fasasi",
        "Ibikunle",
        "Ilori",
        "Ilupeju",
        "Iyanda",
        "Jaiyeola",
        "Kolade",
        "Kosoko",
        "Koya",
        "Makinde",
        "Makinwa",
        "Morawo",
        "Ninalowo",
        "Odetola",
        "Odunsi",
        "Ogindan",
        "Oginni",
        "Ogulana",
        "Ogunbamigbe",
        "Ogunbiyi",
        "Ogunbo",
        "Ogunde",
        "Ogunwobi",
        "Ogunyeye",
        "Ojo",
        "Ojua",
        "Olabode",
        "Oladipupo",
        "Olaiya",
        "Olasupo",
        "Olowokeere",
        "Oloyede",
        "Olubode",
        "Olugbayila",
        "Olujimi",
        "Olukotun",
        "Olukunga",
        "Olusanya",
        "Oluwagbemi",
        "Omidina",
        "Omojola",
        "Omotoso",
        "Oparinde",
        "Oshin",
        "Osuntokun",
        "Owokoniran",
        "Owolabi",
        "Owoyemi",
        "Oyadiran",
        "Oyaifo",
        "Oyeniyi",
        "Oyetoro",
        "Oyeyemi",
        "Oyinlola",
        "Paimo",
        "Salako",
        "Salami",
        "Shekoni",
        "Sobowale",
        "Soyinka",
    )

    # last names are not sex dependant
    last_names_female = last_names_male
    last_names = last_names_male + last_names_female

    prefixes_female = (
        "Mrs.",
        "Ms.",
        "Dr.",
        "Alhaja",
        "Mama",
        "Iya",
        "Madam",
        "Chief",
        "Lady",
        "Erelu",
        "Olori",
        "Princess",
    )

    prefixes_male = (
        "Mr.",
        "Dr.",
        "Alhaji",
        "Baba",
        "Ogbeni",
        "Oloye",
        "Chief",
        "Prince",
        "Oba",
        "Kabiyesi",
    )



from .. import Provider as BankProvider


class Provider(BankProvider):
    """Implement bank provider for ``fa_IR`` locale."""

    bban_format = "IR########################"
    country_code = "IR"
    swift_bank_codes = (
        "BEGN",
        "KESH",
        "BKMN",
        "BKBP",
        "CIYB",
        "BTOS",
        "IVBB",
        "KBID",
        "KIBO",
        "KHMI",
    )
    swift_location_codes = ("TH",)
    swift_branch_codes = ("BSH", "BCQ", "tIR", "tTH", "ATM", "BIC", "TIR", "ASR", "FOR")

    banks = (
        "بانکهای قرض الحسنه",
        "بانک ملّی ایران",
        "بانک اقتصاد نوین",
        "بانک قرض‌الحسنه مهر ایران",
        "بانک سپه",
        "بانک پارسیان",
        "بانک قرض‌الحسنه رسالت",
        "بانک صنعت و معدن",
        "بانک کارآفرین",
        "بانک کشاورزی",
        "بانک سامان",
        "بانک مسکن",
        "بانک سینا",
        "بانک توسعه صادرات ایران",
        "بانک خاور میانه",
        "بانک توسعه تعاون",
        "بانک شهر",
        "پست بانک ایران",
        "بانک دی",
        "بانک صادرات",
        "بانک ملت",
        "بانک تجارت",
        "بانک رفاه",
        "بانک حکمت ایرانیان",
        "بانک گردشگری",
        "بانک ایران زمین",
        "بانک قوامین",
        "بانک انصار",
        "بانک سرمایه",
        "بانک پاسارگاد",
        "بانک مشترک ایران-ونزوئلا",
    )



import string

from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``sk_SK`` locale.

    Sources:

    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Slovakia
    """

    license_plate_prefix = [
        "BA",
        "BL",
        "BT",  # Bratislava
        "BB",  # Banska Bystrica
        "BJ",  # Bardejov
        "BN",  # Banovce nad Bebravou
        "BR",  # Brezno
        "BS",  # Banska Stiavnica
        "BY",  # Bytca
        "CA",  # Cadca
        "DK",  # Dolny Kubin
        "DS",  # Dunajska Streda
        "DT",  # Detva
        "GA",  # Galanta
        "GL",  # Gelnica
        "HC",  # Hlohovec
        "HE",  # Humenne
        "IL",  # Ilava
        "KA",  # Krupina
        "KE",  # Kosice
        "KK",  # Kezmarok
        "KM",  # Kysucke Nove Mesto
        "KN",  # Komarno
        "KS",  # Kosice-okolie
        "LC",  # Lucenec
        "LE",  # Levoca
        "LM",  # Liptovsky Mikulas
        "LV",  # Levice
        "MA",  # Malacky
        "MI",  # Michalovce
        "ML",  # Medzilaborce
        "MT",  # Martin
        "MY",  # Myjava
        "NR",  # Nitra
        "NM",  # Nove Mesto nad Vahom
        "NO",  # Namestovo
        "NZ",  # Nove Zamky
        "PB",  # Povazska Bystrica
        "PD",  # Prievidza
        "PE",  # Partizanske
        "PK",  # Pezinok
        "PN",  # Piestany
        "PO",  # Presov
        "PP",  # Poprad
        "PT",  # Poltar
        "PU",  # Puchov
        "RA",  # Revuca
        "RK",  # Ruzomberok
        "RS",  # Rimavska Sobota
        "RV",  # Roznava
        "SA",  # Sala
        "SB",  # Sabinov
        "SC",  # Senec
        "SE",  # Senica
        "SI",  # Skalica
        "SK",  # Svidnik
        "SL",  # Stara Lubovna
        "SN",  # Spisska Nova Ves
        "SO",  # Sobrance
        "SP",  # Stropkov
        "SV",  # Snina
        "TT",  # Trnava
        "TN",  # Trencin
        "TO",  # Topolcany
        "TR",  # Turcianske Teplice
        "TS",  # Tvrdosin
        "TV",  # Trebisov
        "VK",  # Velky Krtis
        "VT",  # Vranov nad Toplou
        "ZA",  # Zilina
        "ZC",  # Zarnovica
        "ZH",  # Ziar nad Hronom
        "ZM",  # Zlate Moravce
        "ZV",  # Zvolen
    ]

    license_plate_suffix = ("###??",)

    def license_plate(self) -> str:
        """Generate a license plate."""
        prefix: str = self.random_element(self.license_plate_prefix)
        suffix = self.bothify(
            self.random_element(self.license_plate_suffix),
            letters=string.ascii_uppercase,
        )
        return prefix + suffix



from .. import Provider as BaseProvider


class Provider(BaseProvider):
    jobs = [
        "Aktyor",
        "Akustik Mühəndisi",
        "Allerqoloq",
        "Analitik",
        "Androloq",
        "Antropoloq",
        "Aqronom",
        "Aqronom-Torpaqşünas",
        "Arxeoloq",
        "Arxivçi",
        "Astrofizik",
        "Astronom",
        "Aviatexnik",
        "Bakterioloq",
        "Bankir",
        "Barmen",
        "Biokimyaçı",
        "Bioloq",
        "Biomühəndis",
        "Blogger",
        "Botanik",
        "Cihazqayırma və idarəetmə mühəndisi",
        "Coğrafiyaçı",
        "Cərrah",
        "DJ",
        "Dalğıc",
        "Daşçı",
        "Dekan",
        "Dermatoloq",
        "Diler",
        "Diplomat",
        "Diplomatik işçi",
        "Dirijyor",
        "Dispetçer",
        "Dizayner",
        "Dizayner-konstruktor",
        "Dülgər",
        "Elektrikçi",
        "Enerji Mühəndisi",
        "Genetik",
        "Geoloq",
        "Ginekoloq",
        "Gitarist",
        "Gəmi kapitanı",
        "Hematoloq",
        "Hepatoloq",
        "Hidrolik Mühəndis",
        "Hidroloq",
        "Hüquqşünas",
        "Hərbi Hakim",
        "Hərbi Məsləhətçi",
        "Hərbi Polis",
        "Hərbi Prokuror",
        "Hərbi müstəntiq",
        "Hərbi tərcüməçi",
        "Hərbi vəkil",
        "Hərbçi",
        "Jurnalist",
        "Kardioloq",
        "Kimya mühəndisi",
        "Kitabxanaçı",
        "Kolleksiyaçı",
        "Makler",
        "Memar",
        "Mexanik",
        "Mexanika Mühəndisi",
        "Mühasib",
        "Mühəndis",
        "Mühəndis-Fizik",
        "Mühəndis-laboratoriya köməkçisi",
        "Müstəntiq",
        "Mədənçi",
        "Paraşütçü",
        "Partlayıcı Mühəndis",
        "Pilot",
        "Qastroenteroloq",
        "Qulluqçu",
        "Qumbara Atıcı",
        "Reklam dizayneri",
        "Sistem Mühəndisi",
        "Stüardessa",
        "Sürücü",
        "Səs mühəndisi",
        "Tarixçi",
        "Torpaqçı",
        "Təcili yardım həkimi",
        "Təhlükəsizlik Mühəndisi",
        "Təmizlikçi",
        "Təxribatçı",
        "Uçuş mühəndisi",
        "Veb Proqramçı",
        "Verilənlər bazası administratoru",
        "Viroloq",
        "Vizajist",
        "Vokalçı",
        "Webmaster",
        "Xoreoqraf",
        "Zooloq",
        "Zootexnik",
        "Zərgər",
        "Çörəkçi",
        "İmmunoloq",
        "İnfeksionist",
        "İnşaat mühəndisi",
        "İşsiz",
        "Şərqşünas",
    ]



from typing import Tuple

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    street_prefixes = (
        "Strada",
        "Aleea",
        "Intrarea",
        "Bulevardul",
        "Soseaua",
        "Drumul",
    )
    street_name_formats = (
        "{{street_prefix}} {{last_name}}",
        "{{street_prefix}} {{first_name}} {{last_name}}",
        "{{street_prefix}} {{last_name}}",
    )
    street_address_formats = (
        "{{street_name}}",
        "{{street_name}} {{building_number}}",
        "{{street_name}} {{building_number}} {{secondary_address}}",
    )
    address_formats = ("{{street_address}}\n{{city}}, {{postcode}}",)
    building_number_formats = ("Nr. %#", "Nr. %##")
    secondary_address_formats = ("Bl. %#  Sc. %# Ap. %##",)
    postcode_formats = (
        "1#####",
        "2#####",
        "3#####",
        "4#####",
        "5#####",
        "6#####",
        "7#####",
        "8#####",
        "9#####",
    )
    city_formats = ("{{city_name}}",)
    cities = (
        "Cluj-Napoca",
        "Timisoara",
        "Iasi",
        "Constanta",
        "Craiova",
        "Brasov",
        "Galati",
        "Ploiesti",
        "Oradea",
        "Braila",
        "Arad",
        "Pitesti",
        "Sibiu",
        "Bacau",
        "Targu Mures",
        "Baia Mare",
        "Buzau",
        "Botosani",
        "Satu Mare",
        "Suceava",
        "Ramnicu Valcea",
        "Drobeta-Turnu Severin",
        "Piatra-Neamt",
        "Targoviste",
        "Targu Jiu",
        "Focsani",
        "Tulcea",
        "Resita",
        "Slatina",
        "Bistrita",
        "Calarasi",
        "Giurgiu",
        "Deva",
        "Hunedoara",
        "Zalau",
        "Barlad",
        "Alba Iulia",
        "Sfantu Gheorghe",
        "Roman",
        "Vaslui",
        "Turda",
        "Medias",
        "Alexandria",
        "Voluntari",
        "Pipera (Voluntari)",
        "Slobozia",
        "Lugoj",
        "Medgidia",
        "Onesti",
        "Miercurea-Ciuc",
        "Petrosani",
        "Tecuci",
        "Mangalia",
        "Odorheiu Secuiesc",
        "Ramnicu Sarat",
        "Sighetu Marmatiei",
        "Campina",
        "Navodari",
        "Campulung",
        "Caracal",
        "Sacele",
        "Fagaras",
        "Dej",
        "Rosiori de Vede",
        "Mioveni",
        "Curtea de Arges",
        "Husi",
        "Reghin",
        "Sighisoara",
        "Pantelimon",
        "Pascani",
        "Oltenita",
        "Turnu Magurele",
        "Caransebes",
        "Falticeni",
        "Radauti",
        "Lupeni",
        "Dorohoi",
        "Vulcan",
        "Campia Turzii",
        "Zarnesti",
        "Borsa",
        "Popesti-Leordeni",
        "Codlea",
        "Carei",
        "Moinesti",
        "Petrila",
        "Sebes",
        "Tarnaveni",
        "Floresti",
        "Gherla",
        "Fetesti-Gara",
        "Buftea",
        "Cugir",
        "Moreni",
        "Gheorgheni",
        "Comanesti",
        "Salonta",
        "Cernavoda",
        "Targu Secuiesc",
        "Bailesti",
        "Campulung Moldovenesc",
        "Aiud",
        "Dragasani",
        "Valea Caselor (Dragasani)",
        "Bals",
        "Bocsa",
        "Motru",
        "Corabia",
        "Bragadiru",
        "Urziceni",
        "Rasnov",
        "Rasnov Romacril",
        "Buhusi",
        "Zimnicea",
        "Marghita",
        "Mizil",
        "Cisnadie",
        "Targu Neamt",
        "Calafat",
        "Vatra Dornei",
        "Adjud",
        "Gaesti",
        "Tandarei",
        "Gura Humorului",
        "Chitila",
        "Viseu de Sus",
        "Otopeni",
        "Ludus",
        "Brad",
        "Dragu-Brad",
        "Valu lui Traian",
        "Cumpana",
        "Sannicolau Mare",
        "Valenii de Munte",
        "Jilava",
        "Dabuleni",
        "Filiasi",
        "Blaj",
        "Ovidiu",
        "Simleu Silvaniei",
        "Matca",
        "Pecica",
        "Rovinari",
        "Videle",
        "Baicoi",
        "Pucioasa",
        "Jimbolia",
        "Baia Sprie",
        "Targu Frumos",
        "Vicovu de Sus",
        "Orsova",
        "Sinaia",
        "Negresti-Oas",
        "Beius",
        "Santana",
        "Pechea",
        "Simeria",
        "Boldesti-Scaeni",
        "Poienile de sub Munte",
        "Valea lui Mihai",
        "Covasna",
        "Targu Ocna",
        "Toplita",
        "Sovata",
        "Otelu Rosu",
        "Oravita",
        "Moisei",
        "Harsova",
        "Murfatlar",
        "Beclean",
        "Poiana Mare",
        "Huedin",
        "Babadag",
        "Marasesti",
        "Topoloveni",
        "Sangeorgiu de Mures",
        "Jibou",
        "Sabaoani",
        "Hateg",
        "Avrig",
        "Darmanesti",
        "Marginea",
        "Moldova Veche",
        "Ineu",
        "Bolintin-Vale",
        "Mihail Kogalniceanu",
        "Macin",
        "Tomesti",
        "Nasaud",
        "Uricani",
        "Rosu",
        "Calan",
        "Borcea",
        "Afumati",
        "Domnesti",
        "Draganesti-Olt",
        "Cristuru Secuiesc",
        "1 Decembrie",
        "Lumina",
        "Fetesti",
        "Mogosoaia",
        "Modelu",
        "Dumbravita",
        "Seini",
        "Alesd",
        "Sangeorz-Bai",
        "Curtici",
        "Darabani",
        "Nadlac",
        "Victoria",
        "Amara",
        "Branesti",
        "Harlau",
        "Lipova",
        "Techirghiol",
        "Agnita",
        "Sacueni",
        "Titu",
        "Siret",
        "Segarcea",
        "Odobesti",
        "Podu Iloaiei",
        "Ocna Mures",
        "Urlati",
        "Strehaia",
        "Tasnad",
        "Cajvana",
        "Tuzla",
        "Sadova",
        "Vlahita",
        "Stei",
        "Diosig",
        "Cobadin",
        "Gilau",
        "Vladimirescu",
        "Dancu",
        "Bumbesti-Jiu",
        "Busteni",
        "Peretu",
        "Cudalbi",
        "Bosanci",
        "Balotesti",
        "Lunca Cetatuii",
        "Dragalina",
        "Fieni",
        "Chisineu-Cris",
        "Balan",
        "Sandominic",
        "Strejnicu",
        "Baciu",
        "Fundulea",
        "Remetea",
        "Fagetel (Remetea)",
        "Ianca",
        "Roseti",
        "Breaza de Sus",
        "Cornetu",
        "Insuratei",
        "Apahida",
        "Berceni",
        "Vicovu de Jos",
        "Savinesti (Poiana Teiului)",
        "Savinesti",
        "Teius",
        "Barbulesti",
        "Plosca",
        "Toflea",
        "Magurele",
        "Feldru",
        "Anina",
        "Negresti",
        "Valea Mare (Negresti)",
        "Peris",
        "Fundeni",
        "Giroc",
        "Baile Borsa",
        "Oituz",
        "Rucar",
        "Curcani",
        "Babeni",
        "Valea Mare (Babeni)",
        "Rodna",
        "Deta",
        "Ruscova",
        "Intorsura Buzaului",
        "Pancota",
        "Glina",
        "Talmaciu",
        "Copsa Mica",
        "Motatei",
        "Gugesti",
        "Schela Cladovei",
        "Sancraiu de Mures",
        "Iernut",
        "Targu Lapus",
        "Maieru",
        "Prejmer",
        "Pogoanele",
        "Dobroesti",
        "Baraolt",
        "Arbore",
        "Homocea",
        "Corund",
        "Tufesti",
        "Giarmata",
        "Baia",
        "Dumbraveni",
        "Eforie Nord",
        "Horodnic de Sus",
        "Greci",
        "Tudora",
        "Straja",
        "Rasinari",
        "Sebis",
        "Raducaneni",
        "Siria",
        "Paunesti",
        "Saveni",
        "Tunari",
    )

    states: Tuple[Tuple[str, str], ...] = (
        ("AB", "Alba"),
        ("AG", "Argeș"),
        ("AR", "Arad"),
        ("B", "București"),
        ("BC", "Bacău"),
        ("BH", "Bihor"),
        ("BN", "Bistrița-Năsăud"),
        ("BR", "Brăila"),
        ("BT", "Botoșani"),
        ("BV", "Brașov"),
        ("BZ", "Buzău"),
        ("CJ", "Cluj"),
        ("CL", "Călărași"),
        ("CS", "Caraș Severin"),
        ("CT", "Constanța"),
        ("CV", "Covasna"),
        ("DB", "Dâmbovița"),
        ("DJ", "Dolj"),
        ("GJ", "Gorj"),
        ("GL", "Galați"),
        ("GR", "Giurgiu"),
        ("HD", "Hunedoara"),
        ("HR", "Harghita"),
        ("IF", "Ilfov"),
        ("IL", "Ialomița"),
        ("IS", "Iași"),
        ("MH", "Mehedinți"),
        ("MM", "Maramureș"),
        ("MS", "Mureș"),
        ("NT", "Neamț"),
        ("OT", "Olt"),
        ("PH", "Prahova"),
        ("SB", "Sibiu"),
        ("SJ", "Sălaj"),
        ("SM", "Satu Mare"),
        ("SV", "Suceava"),
        ("TL", "Tulcea"),
        ("TM", "Timiș"),
        ("TR", "Teleorman"),
        ("VL", "Vâlcea"),
        ("VN", "Vrancea"),
        ("VS", "Vaslui"),
    )

    def street_prefix(self) -> str:
        """
        :example: 'Strada'
        """
        return self.random_element(self.street_prefixes)

    def secondary_address(self) -> str:
        """
        :example: 'Bl. 123 Sc. 2 Ap. 15'
        """
        return self.numerify(self.random_element(self.secondary_address_formats))

    def city_name(self) -> str:
        return self.random_element(self.cities)

    def city_with_postcode(self) -> str:
        return self.postcode() + " " + self.random_element(self.cities)

    def administrative_unit(self) -> str:
        """
        :example: u'Timiș'
        """
        return self.random_element(self.states)[1]  # type: ignore

    state = administrative_unit

    def state_abbr(self) -> str:
        """
        :example: u'TM'
        """
        return self.random_element(self.states)[0]  # type: ignore



from ..en import Provider as AddressProvider


class Provider(AddressProvider):
    city_prefixes = (
        "North",
        "East",
        "West",
        "South",
        "New",
        "Lake",
        "Port",
        "Upper",
        "Lower",
        "High",
        "Mount",
    )

    city_suffixes = (
        "town",
        "ton",
        "land",
        "ville",
        "berg",
        "burgh",
        "borough",
        "bury",
        "burn",
        "ing",
        "port",
        "mouth",
        "stone",
        "ings",
        "mouth",
        "fort",
        "haven",
        "leigh",
        "side",
        "gate",
        "neath",
        "side",
        " Flats",
        " Hill",
    )

    building_number_formats = ("%##", "%#", "%")

    street_suffixes = (
        # Most common:
        "Arcade",
        "Arcade",
        "Arcade",
        "Avenue",
        "Avenue",
        "Avenue",
        "Avenue",
        "Avenue",
        "Avenue",
        "Avenue",
        "Avenue",
        "Beach Road",
        "Beach Road",
        "Beach Road",
        "Beach Road",
        "Crescent",
        "Crescent",
        "Crescent",
        "Crescent",
        "Crescent",
        "Drive",
        "Drive",
        "Drive",
        "Drive",
        "Mews",
        "Mews",
        "Mews",
        "Place",
        "Place",
        "Place",
        "Place",
        "Range Road",
        "Range Road",
        "Road",
        "Road",
        "Road",
        "Road",
        "Road",
        "Road",
        "Road",
        "Road",
        "Road",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Street",
        "Terrace",
        "Terrace",
        "Terrace",
        "Way",
        "Way",
        "Way",
        # Other:
        "Access",
        "Alley",
        "Alleyway",
        "Amble",
        "Anchorage",
        "Approach",
        "Broadway",
        "Bypass",
        "Causeway",
        "Centre",
        "Circle",
        "Circuit",
        "Close",
        "Concourse",
        "Copse",
        "Corner",
        "Court",
        "Cove",
        "Crest",
        "Cross",
        "Crossing",
        "Cutting",
        "Esplanade",
        "Flats",
        "Gardens",
        "Grove",
        "Heights",
        "Highway",
        "Lane",
        "Line",
        "Keys",
        "Parade",
        "Park",
        "Pass",
        "Plaza",
        "Point",
        "Quay",
        "Reserve",
        "Ridge",
        "Rise",
        "Square",
        "Track",
        "Trail",
        "View",
    )

    # Māori nouns commonly present in placenames.
    te_reo_parts = (
        "ara",
        "awa",
        "horo",
        "kawa",
        "koro",
        "kowhai",
        "manawa",
        "mata",
        "maunga",
        "moko",
        "motu",
        "ngauru",
        "pa" "papa",
        "po",
        "puke",
        "rangi",
        "rohe",
        "rongo",
        "roto",
        "tahi",
        "tai",
        "tangi",
        "tau",
        "tere",
        "tipu",
        "wai",
        "waka",
        "whaka",
        "whanga",
        "whare",
        "weka",
    )

    # Māori endings (usually adjectives) commonly present in placenames.
    te_reo_endings = (
        "hanga",
        "hope",
        "iti",
        "iti",
        "kiwi",
        "makau",
        "nui",
        "nui",
        "nui",
        "nuku",
        "roa",
        "rua",
        "tanga",
        "tapu",
        "toa",
        "whenua",
        "whero",
        "whitu",
    )

    postcode_formats = (
        # as per https://en.wikipedia.org/wiki/Postcodes_in_New_Zealand
        # Northland
        "0%##",
        # Auckland
        "1###",
        "20##",
        "21##",
        "22##",
        "23##",
        "24##",
        "25##",
        "26##",
        # Central North Island
        "3###",
        "4###",
        # Lower North Island
        "50##",
        "51##",
        "52##",
        "53##",
        "55##",
        "57##",
        "58##",
        # Wellington
        "60##",
        "61##",
        "62##",
        "64##",
        "69##",
        # Upper South Island
        "7###",
        # Christchurch
        "80##",
        "81##",
        "82##",
        "84##",
        "85##",
        "86##",
        "88##",
        "89##",
        # Southland
        "90##",
        "92##",
        "93##",
        "94##",
        "95##",
        "96##",
        "97##",
        "98##",
    )

    city_formats = (
        "{{first_name}}{{city_suffix}}",
        "{{last_name}}{{city_suffix}}",
        "{{last_name}}{{city_suffix}}",
        "{{last_name}}{{city_suffix}}",
        "{{last_name}}{{city_suffix}}",
        "{{last_name}}{{city_suffix}}",
        "{{city_prefix}} {{last_name}}{{city_suffix}}",
        "{{te_reo_first}}{{te_reo_ending}}",
        "{{te_reo_first}}{{te_reo_ending}}",
        "{{te_reo_first}}{{te_reo_ending}}",
        "{{te_reo_first}}{{te_reo_ending}}",
        "{{te_reo_first}}{{te_reo_part}}{{te_reo_ending}}",
        "{{te_reo_first}}{{te_reo_part}}{{te_reo_ending}}",
    )

    street_name_formats = (
        "{{first_name}} {{street_suffix}}",
        "{{last_name}} {{street_suffix}}",
        "{{last_name}} {{street_suffix}}",
        "{{last_name}} {{street_suffix}}",
        "{{last_name}}-{{last_name}} {{street_suffix}}",
        "{{te_reo_first}}{{te_reo_ending}} {{street_suffix}}",
        "{{te_reo_first}}{{te_reo_ending}} {{street_suffix}}",
        "{{te_reo_first}}{{te_reo_part}}{{te_reo_ending}} {{street_suffix}}",
    )

    street_address_formats = (
        "{{building_number}} {{street_name}}",
        "{{building_number}} {{street_name}}",
        "{{building_number}} {{street_name}}",
        "{{building_number}} {{street_name}}\nRD {{rd_number}}",
        "{{secondary_address}}\n{{building_number}} {{street_name}}",
        "PO Box {{building_number}}",
    )

    address_formats = ("{{street_address}}\n{{city}} {{postcode}}",)

    secondary_address_formats = (
        "Apt. %##",
        "Flat %#",
        "Suite %##",
        "Unit %#",
        "Level %",
    )

    def te_reo_part(self) -> str:
        return self.random_element(self.te_reo_parts)

    def te_reo_first(self) -> str:
        return str(self.random_element(self.te_reo_parts)).capitalize()

    def te_reo_ending(self) -> str:
        return self.random_element(self.te_reo_parts + self.te_reo_endings)

    def city_prefix(self) -> str:
        return self.random_element(self.city_prefixes)

    def city_suffix(self) -> str:
        return self.random_element(self.city_suffixes)

    def rd_number(self) -> str:
        return self.random_element([str(i) for i in range(1, 11)])

    def secondary_address(self) -> str:
        return self.numerify(self.random_element(self.secondary_address_formats))
